# Automatically generated by scripts/gen_mapfiles.py.
# DO NOT EDIT BY HAND; run `make mapfiles` instead.

LEXERS = {
    "ABAPLexer": (
        "pip._vendor.pygments.lexers.business",
        "ABAP",
        ("abap",),
        ("*.abap", "*.ABAP"),
        ("text/x-abap",),
    ),
    "AMDGPULexer": (
        "pip._vendor.pygments.lexers.amdgpu",
        "AMDGPU",
        ("amdgpu",),
        ("*.isa",),
        (),
    ),
    "APLLexer": (
        "pip._vendor.pygments.lexers.apl",
        "APL",
        ("apl",),
        ("*.apl", "*.aplf", "*.aplo", "*.apln", "*.aplc", "*.apli", "*.dyalog"),
        (),
    ),
    "AbnfLexer": (
        "pip._vendor.pygments.lexers.grammar_notation",
        "ABNF",
        ("abnf",),
        ("*.abnf",),
        ("text/x-abnf",),
    ),
    "ActionScript3Lexer": (
        "pip._vendor.pygments.lexers.actionscript",
        "ActionScript 3",
        ("actionscript3", "as3"),
        ("*.as",),
        ("application/x-actionscript3", "text/x-actionscript3", "text/actionscript3"),
    ),
    "ActionScriptLexer": (
        "pip._vendor.pygments.lexers.actionscript",
        "ActionScript",
        ("actionscript", "as"),
        ("*.as",),
        ("application/x-actionscript", "text/x-actionscript", "text/actionscript"),
    ),
    "AdaLexer": (
        "pip._vendor.pygments.lexers.ada",
        "Ada",
        ("ada", "ada95", "ada2005"),
        ("*.adb", "*.ads", "*.ada"),
        ("text/x-ada",),
    ),
    "AdlLexer": (
        "pip._vendor.pygments.lexers.archetype",
        "ADL",
        ("adl",),
        ("*.adl", "*.adls", "*.adlf", "*.adlx"),
        (),
    ),
    "AgdaLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Agda",
        ("agda",),
        ("*.agda",),
        ("text/x-agda",),
    ),
    "AheuiLexer": (
        "pip._vendor.pygments.lexers.esoteric",
        "Aheui",
        ("aheui",),
        ("*.aheui",),
        (),
    ),
    "AlloyLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Alloy",
        ("alloy",),
        ("*.als",),
        ("text/x-alloy",),
    ),
    "AmbientTalkLexer": (
        "pip._vendor.pygments.lexers.ambient",
        "AmbientTalk",
        ("ambienttalk", "ambienttalk/2", "at"),
        ("*.at",),
        ("text/x-ambienttalk",),
    ),
    "AmplLexer": (
        "pip._vendor.pygments.lexers.ampl",
        "Ampl",
        ("ampl",),
        ("*.run",),
        (),
    ),
    "Angular2HtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML + Angular2",
        ("html+ng2",),
        ("*.ng2",),
        (),
    ),
    "Angular2Lexer": (
        "pip._vendor.pygments.lexers.templates",
        "Angular2",
        ("ng2",),
        (),
        (),
    ),
    "AntlrActionScriptLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With ActionScript Target",
        ("antlr-actionscript", "antlr-as"),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrCSharpLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With C# Target",
        ("antlr-csharp", "antlr-c#"),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrCppLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With CPP Target",
        ("antlr-cpp",),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrJavaLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With Java Target",
        ("antlr-java",),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrLexer": ("pip._vendor.pygments.lexers.parsers", "ANTLR", ("antlr",), (), ()),
    "AntlrObjectiveCLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With ObjectiveC Target",
        ("antlr-objc",),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrPerlLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With Perl Target",
        ("antlr-perl",),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrPythonLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With Python Target",
        ("antlr-python",),
        ("*.G", "*.g"),
        (),
    ),
    "AntlrRubyLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "ANTLR With Ruby Target",
        ("antlr-ruby", "antlr-rb"),
        ("*.G", "*.g"),
        (),
    ),
    "ApacheConfLexer": (
        "pip._vendor.pygments.lexers.configs",
        "ApacheConf",
        ("apacheconf", "aconf", "apache"),
        (".htaccess", "apache.conf", "apache2.conf"),
        ("text/x-apacheconf",),
    ),
    "AppleScriptLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "AppleScript",
        ("applescript",),
        ("*.applescript",),
        (),
    ),
    "ArduinoLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "Arduino",
        ("arduino",),
        ("*.ino",),
        ("text/x-arduino",),
    ),
    "ArrowLexer": (
        "pip._vendor.pygments.lexers.arrow",
        "Arrow",
        ("arrow",),
        ("*.arw",),
        (),
    ),
    "AscLexer": (
        "pip._vendor.pygments.lexers.asc",
        "ASCII armored",
        ("asc", "pem"),
        (
            "*.asc",
            "*.pem",
            "id_dsa",
            "id_ecdsa",
            "id_ecdsa_sk",
            "id_ed25519",
            "id_ed25519_sk",
            "id_rsa",
        ),
        (
            "application/pgp-keys",
            "application/pgp-encrypted",
            "application/pgp-signature",
        ),
    ),
    "AspectJLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "AspectJ",
        ("aspectj",),
        ("*.aj",),
        ("text/x-aspectj",),
    ),
    "AsymptoteLexer": (
        "pip._vendor.pygments.lexers.graphics",
        "Asymptote",
        ("asymptote", "asy"),
        ("*.asy",),
        ("text/x-asymptote",),
    ),
    "AugeasLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Augeas",
        ("augeas",),
        ("*.aug",),
        (),
    ),
    "AutoItLexer": (
        "pip._vendor.pygments.lexers.automation",
        "AutoIt",
        ("autoit",),
        ("*.au3",),
        ("text/x-autoit",),
    ),
    "AutohotkeyLexer": (
        "pip._vendor.pygments.lexers.automation",
        "autohotkey",
        ("autohotkey", "ahk"),
        ("*.ahk", "*.ahkl"),
        ("text/x-autohotkey",),
    ),
    "AwkLexer": (
        "pip._vendor.pygments.lexers.textedit",
        "Awk",
        ("awk", "gawk", "mawk", "nawk"),
        ("*.awk",),
        ("application/x-awk",),
    ),
    "BBCBasicLexer": (
        "pip._vendor.pygments.lexers.basic",
        "BBC Basic",
        ("bbcbasic",),
        ("*.bbc",),
        (),
    ),
    "BBCodeLexer": (
        "pip._vendor.pygments.lexers.markup",
        "BBCode",
        ("bbcode",),
        (),
        ("text/x-bbcode",),
    ),
    "BCLexer": ("pip._vendor.pygments.lexers.algebra", "BC", ("bc",), ("*.bc",), ()),
    "BSTLexer": (
        "pip._vendor.pygments.lexers.bibtex",
        "BST",
        ("bst", "bst-pybtex"),
        ("*.bst",),
        (),
    ),
    "BareLexer": (
        "pip._vendor.pygments.lexers.bare",
        "BARE",
        ("bare",),
        ("*.bare",),
        (),
    ),
    "BaseMakefileLexer": (
        "pip._vendor.pygments.lexers.make",
        "Base Makefile",
        ("basemake",),
        (),
        (),
    ),
    "BashLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Bash",
        ("bash", "sh", "ksh", "zsh", "shell"),
        (
            "*.sh",
            "*.ksh",
            "*.bash",
            "*.ebuild",
            "*.eclass",
            "*.exheres-0",
            "*.exlib",
            "*.zsh",
            ".bashrc",
            "bashrc",
            ".bash_*",
            "bash_*",
            "zshrc",
            ".zshrc",
            ".kshrc",
            "kshrc",
            "PKGBUILD",
        ),
        ("application/x-sh", "application/x-shellscript", "text/x-shellscript"),
    ),
    "BashSessionLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Bash Session",
        ("console", "shell-session"),
        ("*.sh-session", "*.shell-session"),
        ("application/x-shell-session", "application/x-sh-session"),
    ),
    "BatchLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Batchfile",
        ("batch", "bat", "dosbatch", "winbatch"),
        ("*.bat", "*.cmd"),
        ("application/x-dos-batch",),
    ),
    "BddLexer": (
        "pip._vendor.pygments.lexers.bdd",
        "Bdd",
        ("bdd",),
        ("*.feature",),
        ("text/x-bdd",),
    ),
    "BefungeLexer": (
        "pip._vendor.pygments.lexers.esoteric",
        "Befunge",
        ("befunge",),
        ("*.befunge",),
        ("application/x-befunge",),
    ),
    "BerryLexer": (
        "pip._vendor.pygments.lexers.berry",
        "Berry",
        ("berry", "be"),
        ("*.be",),
        ("text/x-berry", "application/x-berry"),
    ),
    "BibTeXLexer": (
        "pip._vendor.pygments.lexers.bibtex",
        "BibTeX",
        ("bibtex", "bib"),
        ("*.bib",),
        ("text/x-bibtex",),
    ),
    "BlitzBasicLexer": (
        "pip._vendor.pygments.lexers.basic",
        "BlitzBasic",
        ("blitzbasic", "b3d", "bplus"),
        ("*.bb", "*.decls"),
        ("text/x-bb",),
    ),
    "BlitzMaxLexer": (
        "pip._vendor.pygments.lexers.basic",
        "BlitzMax",
        ("blitzmax", "bmax"),
        ("*.bmx",),
        ("text/x-bmx",),
    ),
    "BnfLexer": (
        "pip._vendor.pygments.lexers.grammar_notation",
        "BNF",
        ("bnf",),
        ("*.bnf",),
        ("text/x-bnf",),
    ),
    "BoaLexer": ("pip._vendor.pygments.lexers.boa", "Boa", ("boa",), ("*.boa",), ()),
    "BooLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "Boo",
        ("boo",),
        ("*.boo",),
        ("text/x-boo",),
    ),
    "BoogieLexer": (
        "pip._vendor.pygments.lexers.verification",
        "Boogie",
        ("boogie",),
        ("*.bpl",),
        (),
    ),
    "BrainfuckLexer": (
        "pip._vendor.pygments.lexers.esoteric",
        "Brainfuck",
        ("brainfuck", "bf"),
        ("*.bf", "*.b"),
        ("application/x-brainfuck",),
    ),
    "BugsLexer": (
        "pip._vendor.pygments.lexers.modeling",
        "BUGS",
        ("bugs", "winbugs", "openbugs"),
        ("*.bug",),
        (),
    ),
    "CAmkESLexer": (
        "pip._vendor.pygments.lexers.esoteric",
        "CAmkES",
        ("camkes", "idl4"),
        ("*.camkes", "*.idl4"),
        (),
    ),
    "CLexer": (
        "pip._vendor.pygments.lexers.c_cpp",
        "C",
        ("c",),
        ("*.c", "*.h", "*.idc", "*.x[bp]m"),
        ("text/x-chdr", "text/x-csrc", "image/x-xbitmap", "image/x-xpixmap"),
    ),
    "CMakeLexer": (
        "pip._vendor.pygments.lexers.make",
        "CMake",
        ("cmake",),
        ("*.cmake", "CMakeLists.txt"),
        ("text/x-cmake",),
    ),
    "CObjdumpLexer": (
        "pip._vendor.pygments.lexers.asm",
        "c-objdump",
        ("c-objdump",),
        ("*.c-objdump",),
        ("text/x-c-objdump",),
    ),
    "CPSALexer": (
        "pip._vendor.pygments.lexers.lisp",
        "CPSA",
        ("cpsa",),
        ("*.cpsa",),
        (),
    ),
    "CSSUL4Lexer": (
        "pip._vendor.pygments.lexers.ul4",
        "CSS+UL4",
        ("css+ul4",),
        ("*.cssul4",),
        (),
    ),
    "CSharpAspxLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "aspx-cs",
        ("aspx-cs",),
        ("*.aspx", "*.asax", "*.ascx", "*.ashx", "*.asmx", "*.axd"),
        (),
    ),
    "CSharpLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "C#",
        ("csharp", "c#", "cs"),
        ("*.cs",),
        ("text/x-csharp",),
    ),
    "Ca65Lexer": (
        "pip._vendor.pygments.lexers.asm",
        "ca65 assembler",
        ("ca65",),
        ("*.s",),
        (),
    ),
    "CadlLexer": (
        "pip._vendor.pygments.lexers.archetype",
        "cADL",
        ("cadl",),
        ("*.cadl",),
        (),
    ),
    "CapDLLexer": (
        "pip._vendor.pygments.lexers.esoteric",
        "CapDL",
        ("capdl",),
        ("*.cdl",),
        (),
    ),
    "CapnProtoLexer": (
        "pip._vendor.pygments.lexers.capnproto",
        "Cap'n Proto",
        ("capnp",),
        ("*.capnp",),
        (),
    ),
    "CbmBasicV2Lexer": (
        "pip._vendor.pygments.lexers.basic",
        "CBM BASIC V2",
        ("cbmbas",),
        ("*.bas",),
        (),
    ),
    "CddlLexer": (
        "pip._vendor.pygments.lexers.cddl",
        "CDDL",
        ("cddl",),
        ("*.cddl",),
        ("text/x-cddl",),
    ),
    "CeylonLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Ceylon",
        ("ceylon",),
        ("*.ceylon",),
        ("text/x-ceylon",),
    ),
    "Cfengine3Lexer": (
        "pip._vendor.pygments.lexers.configs",
        "CFEngine3",
        ("cfengine3", "cf3"),
        ("*.cf",),
        (),
    ),
    "ChaiscriptLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "ChaiScript",
        ("chaiscript", "chai"),
        ("*.chai",),
        ("text/x-chaiscript", "application/x-chaiscript"),
    ),
    "ChapelLexer": (
        "pip._vendor.pygments.lexers.chapel",
        "Chapel",
        ("chapel", "chpl"),
        ("*.chpl",),
        (),
    ),
    "CharmciLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "Charmci",
        ("charmci",),
        ("*.ci",),
        (),
    ),
    "CheetahHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Cheetah",
        ("html+cheetah", "html+spitfire", "htmlcheetah"),
        (),
        ("text/html+cheetah", "text/html+spitfire"),
    ),
    "CheetahJavascriptLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Cheetah",
        ("javascript+cheetah", "js+cheetah", "javascript+spitfire", "js+spitfire"),
        (),
        (
            "application/x-javascript+cheetah",
            "text/x-javascript+cheetah",
            "text/javascript+cheetah",
            "application/x-javascript+spitfire",
            "text/x-javascript+spitfire",
            "text/javascript+spitfire",
        ),
    ),
    "CheetahLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Cheetah",
        ("cheetah", "spitfire"),
        ("*.tmpl", "*.spt"),
        ("application/x-cheetah", "application/x-spitfire"),
    ),
    "CheetahXmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Cheetah",
        ("xml+cheetah", "xml+spitfire"),
        (),
        ("application/xml+cheetah", "application/xml+spitfire"),
    ),
    "CirruLexer": (
        "pip._vendor.pygments.lexers.webmisc",
        "Cirru",
        ("cirru",),
        ("*.cirru",),
        ("text/x-cirru",),
    ),
    "ClayLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "Clay",
        ("clay",),
        ("*.clay",),
        ("text/x-clay",),
    ),
    "CleanLexer": (
        "pip._vendor.pygments.lexers.clean",
        "Clean",
        ("clean",),
        ("*.icl", "*.dcl"),
        (),
    ),
    "ClojureLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Clojure",
        ("clojure", "clj"),
        ("*.clj", "*.cljc"),
        ("text/x-clojure", "application/x-clojure"),
    ),
    "ClojureScriptLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "ClojureScript",
        ("clojurescript", "cljs"),
        ("*.cljs",),
        ("text/x-clojurescript", "application/x-clojurescript"),
    ),
    "CobolFreeformatLexer": (
        "pip._vendor.pygments.lexers.business",
        "COBOLFree",
        ("cobolfree",),
        ("*.cbl", "*.CBL"),
        (),
    ),
    "CobolLexer": (
        "pip._vendor.pygments.lexers.business",
        "COBOL",
        ("cobol",),
        ("*.cob", "*.COB", "*.cpy", "*.CPY"),
        ("text/x-cobol",),
    ),
    "CoffeeScriptLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "CoffeeScript",
        ("coffeescript", "coffee-script", "coffee"),
        ("*.coffee",),
        ("text/coffeescript",),
    ),
    "ColdfusionCFCLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Coldfusion CFC",
        ("cfc",),
        ("*.cfc",),
        (),
    ),
    "ColdfusionHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Coldfusion HTML",
        ("cfm",),
        ("*.cfm", "*.cfml"),
        ("application/x-coldfusion",),
    ),
    "ColdfusionLexer": (
        "pip._vendor.pygments.lexers.templates",
        "cfstatement",
        ("cfs",),
        (),
        (),
    ),
    "Comal80Lexer": (
        "pip._vendor.pygments.lexers.comal",
        "COMAL-80",
        ("comal", "comal80"),
        ("*.cml", "*.comal"),
        (),
    ),
    "CommonLispLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "Common Lisp",
        ("common-lisp", "cl", "lisp"),
        ("*.cl", "*.lisp"),
        ("text/x-common-lisp",),
    ),
    "ComponentPascalLexer": (
        "pip._vendor.pygments.lexers.oberon",
        "Component Pascal",
        ("componentpascal", "cp"),
        ("*.cp", "*.cps"),
        ("text/x-component-pascal",),
    ),
    "CoqLexer": (
        "pip._vendor.pygments.lexers.theorem",
        "Coq",
        ("coq",),
        ("*.v",),
        ("text/x-coq",),
    ),
    "CplintLexer": (
        "pip._vendor.pygments.lexers.cplint",
        "cplint",
        ("cplint",),
        ("*.ecl", "*.prolog", "*.pro", "*.pl", "*.P", "*.lpad", "*.cpl"),
        ("text/x-cplint",),
    ),
    "CppLexer": (
        "pip._vendor.pygments.lexers.c_cpp",
        "C++",
        ("cpp", "c++"),
        (
            "*.cpp",
            "*.hpp",
            "*.c++",
            "*.h++",
            "*.cc",
            "*.hh",
            "*.cxx",
            "*.hxx",
            "*.C",
            "*.H",
            "*.cp",
            "*.CPP",
            "*.tpp",
        ),
        ("text/x-c++hdr", "text/x-c++src"),
    ),
    "CppObjdumpLexer": (
        "pip._vendor.pygments.lexers.asm",
        "cpp-objdump",
        ("cpp-objdump", "c++-objdumb", "cxx-objdump"),
        ("*.cpp-objdump", "*.c++-objdump", "*.cxx-objdump"),
        ("text/x-cpp-objdump",),
    ),
    "CrmshLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Crmsh",
        ("crmsh", "pcmk"),
        ("*.crmsh", "*.pcmk"),
        (),
    ),
    "CrocLexer": (
        "pip._vendor.pygments.lexers.d",
        "Croc",
        ("croc",),
        ("*.croc",),
        ("text/x-crocsrc",),
    ),
    "CryptolLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Cryptol",
        ("cryptol", "cry"),
        ("*.cry",),
        ("text/x-cryptol",),
    ),
    "CrystalLexer": (
        "pip._vendor.pygments.lexers.crystal",
        "Crystal",
        ("cr", "crystal"),
        ("*.cr",),
        ("text/x-crystal",),
    ),
    "CsoundDocumentLexer": (
        "pip._vendor.pygments.lexers.csound",
        "Csound Document",
        ("csound-document", "csound-csd"),
        ("*.csd",),
        (),
    ),
    "CsoundOrchestraLexer": (
        "pip._vendor.pygments.lexers.csound",
        "Csound Orchestra",
        ("csound", "csound-orc"),
        ("*.orc", "*.udo"),
        (),
    ),
    "CsoundScoreLexer": (
        "pip._vendor.pygments.lexers.csound",
        "Csound Score",
        ("csound-score", "csound-sco"),
        ("*.sco",),
        (),
    ),
    "CssDjangoLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Django/Jinja",
        ("css+django", "css+jinja"),
        ("*.css.j2", "*.css.jinja2"),
        ("text/css+django", "text/css+jinja"),
    ),
    "CssErbLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Ruby",
        ("css+ruby", "css+erb"),
        (),
        ("text/css+ruby",),
    ),
    "CssGenshiLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Genshi Text",
        ("css+genshitext", "css+genshi"),
        (),
        ("text/css+genshi",),
    ),
    "CssLexer": (
        "pip._vendor.pygments.lexers.css",
        "CSS",
        ("css",),
        ("*.css",),
        ("text/css",),
    ),
    "CssPhpLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+PHP",
        ("css+php",),
        (),
        ("text/css+php",),
    ),
    "CssSmartyLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Smarty",
        ("css+smarty",),
        (),
        ("text/css+smarty",),
    ),
    "CudaLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "CUDA",
        ("cuda", "cu"),
        ("*.cu", "*.cuh"),
        ("text/x-cuda",),
    ),
    "CypherLexer": (
        "pip._vendor.pygments.lexers.graph",
        "Cypher",
        ("cypher",),
        ("*.cyp", "*.cypher"),
        (),
    ),
    "CythonLexer": (
        "pip._vendor.pygments.lexers.python",
        "Cython",
        ("cython", "pyx", "pyrex"),
        ("*.pyx", "*.pxd", "*.pxi"),
        ("text/x-cython", "application/x-cython"),
    ),
    "DLexer": (
        "pip._vendor.pygments.lexers.d",
        "D",
        ("d",),
        ("*.d", "*.di"),
        ("text/x-dsrc",),
    ),
    "DObjdumpLexer": (
        "pip._vendor.pygments.lexers.asm",
        "d-objdump",
        ("d-objdump",),
        ("*.d-objdump",),
        ("text/x-d-objdump",),
    ),
    "DarcsPatchLexer": (
        "pip._vendor.pygments.lexers.diff",
        "Darcs Patch",
        ("dpatch",),
        ("*.dpatch", "*.darcspatch"),
        (),
    ),
    "DartLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Dart",
        ("dart",),
        ("*.dart",),
        ("text/x-dart",),
    ),
    "Dasm16Lexer": (
        "pip._vendor.pygments.lexers.asm",
        "DASM16",
        ("dasm16",),
        ("*.dasm16", "*.dasm"),
        ("text/x-dasm16",),
    ),
    "DebianControlLexer": (
        "pip._vendor.pygments.lexers.installers",
        "Debian Control file",
        ("debcontrol", "control"),
        ("control",),
        (),
    ),
    "DelphiLexer": (
        "pip._vendor.pygments.lexers.pascal",
        "Delphi",
        ("delphi", "pas", "pascal", "objectpascal"),
        ("*.pas", "*.dpr"),
        ("text/x-pascal",),
    ),
    "DevicetreeLexer": (
        "pip._vendor.pygments.lexers.devicetree",
        "Devicetree",
        ("devicetree", "dts"),
        ("*.dts", "*.dtsi"),
        ("text/x-c",),
    ),
    "DgLexer": (
        "pip._vendor.pygments.lexers.python",
        "dg",
        ("dg",),
        ("*.dg",),
        ("text/x-dg",),
    ),
    "DiffLexer": (
        "pip._vendor.pygments.lexers.diff",
        "Diff",
        ("diff", "udiff"),
        ("*.diff", "*.patch"),
        ("text/x-diff", "text/x-patch"),
    ),
    "DjangoLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Django/Jinja",
        ("django", "jinja"),
        (),
        ("application/x-django-templating", "application/x-jinja"),
    ),
    "DockerLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Docker",
        ("docker", "dockerfile"),
        ("Dockerfile", "*.docker"),
        ("text/x-dockerfile-config",),
    ),
    "DtdLexer": (
        "pip._vendor.pygments.lexers.html",
        "DTD",
        ("dtd",),
        ("*.dtd",),
        ("application/xml-dtd",),
    ),
    "DuelLexer": (
        "pip._vendor.pygments.lexers.webmisc",
        "Duel",
        ("duel", "jbst", "jsonml+bst"),
        ("*.duel", "*.jbst"),
        ("text/x-duel", "text/x-jbst"),
    ),
    "DylanConsoleLexer": (
        "pip._vendor.pygments.lexers.dylan",
        "Dylan session",
        ("dylan-console", "dylan-repl"),
        ("*.dylan-console",),
        ("text/x-dylan-console",),
    ),
    "DylanLexer": (
        "pip._vendor.pygments.lexers.dylan",
        "Dylan",
        ("dylan",),
        ("*.dylan", "*.dyl", "*.intr"),
        ("text/x-dylan",),
    ),
    "DylanLidLexer": (
        "pip._vendor.pygments.lexers.dylan",
        "DylanLID",
        ("dylan-lid", "lid"),
        ("*.lid", "*.hdp"),
        ("text/x-dylan-lid",),
    ),
    "ECLLexer": (
        "pip._vendor.pygments.lexers.ecl",
        "ECL",
        ("ecl",),
        ("*.ecl",),
        ("application/x-ecl",),
    ),
    "ECLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "eC",
        ("ec",),
        ("*.ec", "*.eh"),
        ("text/x-echdr", "text/x-ecsrc"),
    ),
    "EarlGreyLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Earl Grey",
        ("earl-grey", "earlgrey", "eg"),
        ("*.eg",),
        ("text/x-earl-grey",),
    ),
    "EasytrieveLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "Easytrieve",
        ("easytrieve",),
        ("*.ezt", "*.mac"),
        ("text/x-easytrieve",),
    ),
    "EbnfLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "EBNF",
        ("ebnf",),
        ("*.ebnf",),
        ("text/x-ebnf",),
    ),
    "EiffelLexer": (
        "pip._vendor.pygments.lexers.eiffel",
        "Eiffel",
        ("eiffel",),
        ("*.e",),
        ("text/x-eiffel",),
    ),
    "ElixirConsoleLexer": (
        "pip._vendor.pygments.lexers.erlang",
        "Elixir iex session",
        ("iex",),
        (),
        ("text/x-elixir-shellsession",),
    ),
    "ElixirLexer": (
        "pip._vendor.pygments.lexers.erlang",
        "Elixir",
        ("elixir", "ex", "exs"),
        ("*.ex", "*.eex", "*.exs", "*.leex"),
        ("text/x-elixir",),
    ),
    "ElmLexer": (
        "pip._vendor.pygments.lexers.elm",
        "Elm",
        ("elm",),
        ("*.elm",),
        ("text/x-elm",),
    ),
    "ElpiLexer": (
        "pip._vendor.pygments.lexers.elpi",
        "Elpi",
        ("elpi",),
        ("*.elpi",),
        ("text/x-elpi",),
    ),
    "EmacsLispLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "EmacsLisp",
        ("emacs-lisp", "elisp", "emacs"),
        ("*.el",),
        ("text/x-elisp", "application/x-elisp"),
    ),
    "EmailLexer": (
        "pip._vendor.pygments.lexers.email",
        "E-mail",
        ("email", "eml"),
        ("*.eml",),
        ("message/rfc822",),
    ),
    "ErbLexer": (
        "pip._vendor.pygments.lexers.templates",
        "ERB",
        ("erb",),
        (),
        ("application/x-ruby-templating",),
    ),
    "ErlangLexer": (
        "pip._vendor.pygments.lexers.erlang",
        "Erlang",
        ("erlang",),
        ("*.erl", "*.hrl", "*.es", "*.escript"),
        ("text/x-erlang",),
    ),
    "ErlangShellLexer": (
        "pip._vendor.pygments.lexers.erlang",
        "Erlang erl session",
        ("erl",),
        ("*.erl-sh",),
        ("text/x-erl-shellsession",),
    ),
    "EvoqueHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Evoque",
        ("html+evoque",),
        ("*.html",),
        ("text/html+evoque",),
    ),
    "EvoqueLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Evoque",
        ("evoque",),
        ("*.evoque",),
        ("application/x-evoque",),
    ),
    "EvoqueXmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Evoque",
        ("xml+evoque",),
        ("*.xml",),
        ("application/xml+evoque",),
    ),
    "ExeclineLexer": (
        "pip._vendor.pygments.lexers.shell",
        "execline",
        ("execline",),
        ("*.exec",),
        (),
    ),
    "EzhilLexer": (
        "pip._vendor.pygments.lexers.ezhil",
        "Ezhil",
        ("ezhil",),
        ("*.n",),
        ("text/x-ezhil",),
    ),
    "FSharpLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "F#",
        ("fsharp", "f#"),
        ("*.fs", "*.fsi"),
        ("text/x-fsharp",),
    ),
    "FStarLexer": (
        "pip._vendor.pygments.lexers.ml",
        "FStar",
        ("fstar",),
        ("*.fst", "*.fsti"),
        ("text/x-fstar",),
    ),
    "FactorLexer": (
        "pip._vendor.pygments.lexers.factor",
        "Factor",
        ("factor",),
        ("*.factor",),
        ("text/x-factor",),
    ),
    "FancyLexer": (
        "pip._vendor.pygments.lexers.ruby",
        "Fancy",
        ("fancy", "fy"),
        ("*.fy", "*.fancypack"),
        ("text/x-fancysrc",),
    ),
    "FantomLexer": (
        "pip._vendor.pygments.lexers.fantom",
        "Fantom",
        ("fan",),
        ("*.fan",),
        ("application/x-fantom",),
    ),
    "FelixLexer": (
        "pip._vendor.pygments.lexers.felix",
        "Felix",
        ("felix", "flx"),
        ("*.flx", "*.flxh"),
        ("text/x-felix",),
    ),
    "FennelLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "Fennel",
        ("fennel", "fnl"),
        ("*.fnl",),
        (),
    ),
    "FishShellLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Fish",
        ("fish", "fishshell"),
        ("*.fish", "*.load"),
        ("application/x-fish",),
    ),
    "FlatlineLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Flatline",
        ("flatline",),
        (),
        ("text/x-flatline",),
    ),
    "FloScriptLexer": (
        "pip._vendor.pygments.lexers.floscript",
        "FloScript",
        ("floscript", "flo"),
        ("*.flo",),
        (),
    ),
    "ForthLexer": (
        "pip._vendor.pygments.lexers.forth",
        "Forth",
        ("forth",),
        ("*.frt", "*.fs"),
        ("application/x-forth",),
    ),
    "FortranFixedLexer": (
        "pip._vendor.pygments.lexers.fortran",
        "FortranFixed",
        ("fortranfixed",),
        ("*.f", "*.F"),
        (),
    ),
    "FortranLexer": (
        "pip._vendor.pygments.lexers.fortran",
        "Fortran",
        ("fortran", "f90"),
        ("*.f03", "*.f90", "*.F03", "*.F90"),
        ("text/x-fortran",),
    ),
    "FoxProLexer": (
        "pip._vendor.pygments.lexers.foxpro",
        "FoxPro",
        ("foxpro", "vfp", "clipper", "xbase"),
        ("*.PRG", "*.prg"),
        (),
    ),
    "FreeFemLexer": (
        "pip._vendor.pygments.lexers.freefem",
        "Freefem",
        ("freefem",),
        ("*.edp",),
        ("text/x-freefem",),
    ),
    "FutharkLexer": (
        "pip._vendor.pygments.lexers.futhark",
        "Futhark",
        ("futhark",),
        ("*.fut",),
        ("text/x-futhark",),
    ),
    "GAPLexer": (
        "pip._vendor.pygments.lexers.algebra",
        "GAP",
        ("gap",),
        ("*.g", "*.gd", "*.gi", "*.gap"),
        (),
    ),
    "GDScriptLexer": (
        "pip._vendor.pygments.lexers.gdscript",
        "GDScript",
        ("gdscript", "gd"),
        ("*.gd",),
        ("text/x-gdscript", "application/x-gdscript"),
    ),
    "GLShaderLexer": (
        "pip._vendor.pygments.lexers.graphics",
        "GLSL",
        ("glsl",),
        ("*.vert", "*.frag", "*.geo"),
        ("text/x-glslsrc",),
    ),
    "GSQLLexer": (
        "pip._vendor.pygments.lexers.gsql",
        "GSQL",
        ("gsql",),
        ("*.gsql",),
        (),
    ),
    "GasLexer": (
        "pip._vendor.pygments.lexers.asm",
        "GAS",
        ("gas", "asm"),
        ("*.s", "*.S"),
        ("text/x-gas",),
    ),
    "GcodeLexer": (
        "pip._vendor.pygments.lexers.gcodelexer",
        "g-code",
        ("gcode",),
        ("*.gcode",),
        (),
    ),
    "GenshiLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Genshi",
        ("genshi", "kid", "xml+genshi", "xml+kid"),
        ("*.kid",),
        ("application/x-genshi", "application/x-kid"),
    ),
    "GenshiTextLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Genshi Text",
        ("genshitext",),
        (),
        ("application/x-genshi-text", "text/x-genshi"),
    ),
    "GettextLexer": (
        "pip._vendor.pygments.lexers.textfmts",
        "Gettext Catalog",
        ("pot", "po"),
        ("*.pot", "*.po"),
        ("application/x-gettext", "text/x-gettext", "text/gettext"),
    ),
    "GherkinLexer": (
        "pip._vendor.pygments.lexers.testing",
        "Gherkin",
        ("gherkin", "cucumber"),
        ("*.feature",),
        ("text/x-gherkin",),
    ),
    "GnuplotLexer": (
        "pip._vendor.pygments.lexers.graphics",
        "Gnuplot",
        ("gnuplot",),
        ("*.plot", "*.plt"),
        ("text/x-gnuplot",),
    ),
    "GoLexer": (
        "pip._vendor.pygments.lexers.go",
        "Go",
        ("go", "golang"),
        ("*.go",),
        ("text/x-gosrc",),
    ),
    "GoloLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Golo",
        ("golo",),
        ("*.golo",),
        (),
    ),
    "GoodDataCLLexer": (
        "pip._vendor.pygments.lexers.business",
        "GoodData-CL",
        ("gooddata-cl",),
        ("*.gdc",),
        ("text/x-gooddata-cl",),
    ),
    "GosuLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Gosu",
        ("gosu",),
        ("*.gs", "*.gsx", "*.gsp", "*.vark"),
        ("text/x-gosu",),
    ),
    "GosuTemplateLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Gosu Template",
        ("gst",),
        ("*.gst",),
        ("text/x-gosu-template",),
    ),
    "GraphvizLexer": (
        "pip._vendor.pygments.lexers.graphviz",
        "Graphviz",
        ("graphviz", "dot"),
        ("*.gv", "*.dot"),
        ("text/x-graphviz", "text/vnd.graphviz"),
    ),
    "GroffLexer": (
        "pip._vendor.pygments.lexers.markup",
        "Groff",
        ("groff", "nroff", "man"),
        ("*.[1-9]", "*.man", "*.1p", "*.3pm"),
        ("application/x-troff", "text/troff"),
    ),
    "GroovyLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Groovy",
        ("groovy",),
        ("*.groovy", "*.gradle"),
        ("text/x-groovy",),
    ),
    "HLSLShaderLexer": (
        "pip._vendor.pygments.lexers.graphics",
        "HLSL",
        ("hlsl",),
        ("*.hlsl", "*.hlsli"),
        ("text/x-hlsl",),
    ),
    "HTMLUL4Lexer": (
        "pip._vendor.pygments.lexers.ul4",
        "HTML+UL4",
        ("html+ul4",),
        ("*.htmlul4",),
        (),
    ),
    "HamlLexer": (
        "pip._vendor.pygments.lexers.html",
        "Haml",
        ("haml",),
        ("*.haml",),
        ("text/x-haml",),
    ),
    "HandlebarsHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Handlebars",
        ("html+handlebars",),
        ("*.handlebars", "*.hbs"),
        ("text/html+handlebars", "text/x-handlebars-template"),
    ),
    "HandlebarsLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Handlebars",
        ("handlebars",),
        (),
        (),
    ),
    "HaskellLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Haskell",
        ("haskell", "hs"),
        ("*.hs",),
        ("text/x-haskell",),
    ),
    "HaxeLexer": (
        "pip._vendor.pygments.lexers.haxe",
        "Haxe",
        ("haxe", "hxsl", "hx"),
        ("*.hx", "*.hxsl"),
        ("text/haxe", "text/x-haxe", "text/x-hx"),
    ),
    "HexdumpLexer": (
        "pip._vendor.pygments.lexers.hexdump",
        "Hexdump",
        ("hexdump",),
        (),
        (),
    ),
    "HsailLexer": (
        "pip._vendor.pygments.lexers.asm",
        "HSAIL",
        ("hsail", "hsa"),
        ("*.hsail",),
        ("text/x-hsail",),
    ),
    "HspecLexer": ("pip._vendor.pygments.lexers.haskell", "Hspec", ("hspec",), (), ()),
    "HtmlDjangoLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Django/Jinja",
        ("html+django", "html+jinja", "htmldjango"),
        (
            "*.html.j2",
            "*.htm.j2",
            "*.xhtml.j2",
            "*.html.jinja2",
            "*.htm.jinja2",
            "*.xhtml.jinja2",
        ),
        ("text/html+django", "text/html+jinja"),
    ),
    "HtmlGenshiLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Genshi",
        ("html+genshi", "html+kid"),
        (),
        ("text/html+genshi",),
    ),
    "HtmlLexer": (
        "pip._vendor.pygments.lexers.html",
        "HTML",
        ("html",),
        ("*.html", "*.htm", "*.xhtml", "*.xslt"),
        ("text/html", "application/xhtml+xml"),
    ),
    "HtmlPhpLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+PHP",
        ("html+php",),
        ("*.phtml",),
        (
            "application/x-php",
            "application/x-httpd-php",
            "application/x-httpd-php3",
            "application/x-httpd-php4",
            "application/x-httpd-php5",
        ),
    ),
    "HtmlSmartyLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Smarty",
        ("html+smarty",),
        (),
        ("text/html+smarty",),
    ),
    "HttpLexer": ("pip._vendor.pygments.lexers.textfmts", "HTTP", ("http",), (), ()),
    "HxmlLexer": (
        "pip._vendor.pygments.lexers.haxe",
        "Hxml",
        ("haxeml", "hxml"),
        ("*.hxml",),
        (),
    ),
    "HyLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "Hy",
        ("hylang",),
        ("*.hy",),
        ("text/x-hy", "application/x-hy"),
    ),
    "HybrisLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "Hybris",
        ("hybris", "hy"),
        ("*.hy", "*.hyb"),
        ("text/x-hybris", "application/x-hybris"),
    ),
    "IDLLexer": (
        "pip._vendor.pygments.lexers.idl",
        "IDL",
        ("idl",),
        ("*.pro",),
        ("text/idl",),
    ),
    "IconLexer": (
        "pip._vendor.pygments.lexers.unicon",
        "Icon",
        ("icon",),
        ("*.icon", "*.ICON"),
        (),
    ),
    "IdrisLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Idris",
        ("idris", "idr"),
        ("*.idr",),
        ("text/x-idris",),
    ),
    "IgorLexer": (
        "pip._vendor.pygments.lexers.igor",
        "Igor",
        ("igor", "igorpro"),
        ("*.ipf",),
        ("text/ipf",),
    ),
    "Inform6Lexer": (
        "pip._vendor.pygments.lexers.int_fiction",
        "Inform 6",
        ("inform6", "i6"),
        ("*.inf",),
        (),
    ),
    "Inform6TemplateLexer": (
        "pip._vendor.pygments.lexers.int_fiction",
        "Inform 6 template",
        ("i6t",),
        ("*.i6t",),
        (),
    ),
    "Inform7Lexer": (
        "pip._vendor.pygments.lexers.int_fiction",
        "Inform 7",
        ("inform7", "i7"),
        ("*.ni", "*.i7x"),
        (),
    ),
    "IniLexer": (
        "pip._vendor.pygments.lexers.configs",
        "INI",
        ("ini", "cfg", "dosini"),
        (
            "*.ini",
            "*.cfg",
            "*.inf",
            ".editorconfig",
            "*.service",
            "*.socket",
            "*.device",
            "*.mount",
            "*.automount",
            "*.swap",
            "*.target",
            "*.path",
            "*.timer",
            "*.slice",
            "*.scope",
        ),
        ("text/x-ini", "text/inf"),
    ),
    "IoLexer": (
        "pip._vendor.pygments.lexers.iolang",
        "Io",
        ("io",),
        ("*.io",),
        ("text/x-iosrc",),
    ),
    "IokeLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Ioke",
        ("ioke", "ik"),
        ("*.ik",),
        ("text/x-iokesrc",),
    ),
    "IrcLogsLexer": (
        "pip._vendor.pygments.lexers.textfmts",
        "IRC logs",
        ("irc",),
        ("*.weechatlog",),
        ("text/x-irclog",),
    ),
    "IsabelleLexer": (
        "pip._vendor.pygments.lexers.theorem",
        "Isabelle",
        ("isabelle",),
        ("*.thy",),
        ("text/x-isabelle",),
    ),
    "JLexer": ("pip._vendor.pygments.lexers.j", "J", ("j",), ("*.ijs",), ("text/x-j",)),
    "JMESPathLexer": (
        "pip._vendor.pygments.lexers.jmespath",
        "JMESPath",
        ("jmespath", "jp"),
        ("*.jp",),
        (),
    ),
    "JSLTLexer": (
        "pip._vendor.pygments.lexers.jslt",
        "JSLT",
        ("jslt",),
        ("*.jslt",),
        ("text/x-jslt",),
    ),
    "JagsLexer": (
        "pip._vendor.pygments.lexers.modeling",
        "JAGS",
        ("jags",),
        ("*.jag", "*.bug"),
        (),
    ),
    "JasminLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Jasmin",
        ("jasmin", "jasminxt"),
        ("*.j",),
        (),
    ),
    "JavaLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Java",
        ("java",),
        ("*.java",),
        ("text/x-java",),
    ),
    "JavascriptDjangoLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Django/Jinja",
        ("javascript+django", "js+django", "javascript+jinja", "js+jinja"),
        ("*.js.j2", "*.js.jinja2"),
        (
            "application/x-javascript+django",
            "application/x-javascript+jinja",
            "text/x-javascript+django",
            "text/x-javascript+jinja",
            "text/javascript+django",
            "text/javascript+jinja",
        ),
    ),
    "JavascriptErbLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Ruby",
        ("javascript+ruby", "js+ruby", "javascript+erb", "js+erb"),
        (),
        (
            "application/x-javascript+ruby",
            "text/x-javascript+ruby",
            "text/javascript+ruby",
        ),
    ),
    "JavascriptGenshiLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Genshi Text",
        ("js+genshitext", "js+genshi", "javascript+genshitext", "javascript+genshi"),
        (),
        (
            "application/x-javascript+genshi",
            "text/x-javascript+genshi",
            "text/javascript+genshi",
        ),
    ),
    "JavascriptLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "JavaScript",
        ("javascript", "js"),
        ("*.js", "*.jsm", "*.mjs", "*.cjs"),
        (
            "application/javascript",
            "application/x-javascript",
            "text/x-javascript",
            "text/javascript",
        ),
    ),
    "JavascriptPhpLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+PHP",
        ("javascript+php", "js+php"),
        (),
        (
            "application/x-javascript+php",
            "text/x-javascript+php",
            "text/javascript+php",
        ),
    ),
    "JavascriptSmartyLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Smarty",
        ("javascript+smarty", "js+smarty"),
        (),
        (
            "application/x-javascript+smarty",
            "text/x-javascript+smarty",
            "text/javascript+smarty",
        ),
    ),
    "JavascriptUL4Lexer": (
        "pip._vendor.pygments.lexers.ul4",
        "Javascript+UL4",
        ("js+ul4",),
        ("*.jsul4",),
        (),
    ),
    "JclLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "JCL",
        ("jcl",),
        ("*.jcl",),
        ("text/x-jcl",),
    ),
    "JsgfLexer": (
        "pip._vendor.pygments.lexers.grammar_notation",
        "JSGF",
        ("jsgf",),
        ("*.jsgf",),
        ("application/jsgf", "application/x-jsgf", "text/jsgf"),
    ),
    "JsonBareObjectLexer": (
        "pip._vendor.pygments.lexers.data",
        "JSONBareObject",
        (),
        (),
        (),
    ),
    "JsonLdLexer": (
        "pip._vendor.pygments.lexers.data",
        "JSON-LD",
        ("jsonld", "json-ld"),
        ("*.jsonld",),
        ("application/ld+json",),
    ),
    "JsonLexer": (
        "pip._vendor.pygments.lexers.data",
        "JSON",
        ("json", "json-object"),
        ("*.json", "Pipfile.lock"),
        ("application/json", "application/json-object"),
    ),
    "JspLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Java Server Page",
        ("jsp",),
        ("*.jsp",),
        ("application/x-jsp",),
    ),
    "JuliaConsoleLexer": (
        "pip._vendor.pygments.lexers.julia",
        "Julia console",
        ("jlcon", "julia-repl"),
        (),
        (),
    ),
    "JuliaLexer": (
        "pip._vendor.pygments.lexers.julia",
        "Julia",
        ("julia", "jl"),
        ("*.jl",),
        ("text/x-julia", "application/x-julia"),
    ),
    "JuttleLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Juttle",
        ("juttle",),
        ("*.juttle",),
        ("application/juttle", "application/x-juttle", "text/x-juttle", "text/juttle"),
    ),
    "KLexer": ("pip._vendor.pygments.lexers.q", "K", ("k",), ("*.k",), ()),
    "KalLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Kal",
        ("kal",),
        ("*.kal",),
        ("text/kal", "application/kal"),
    ),
    "KconfigLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Kconfig",
        ("kconfig", "menuconfig", "linux-config", "kernel-config"),
        ("Kconfig*", "*Config.in*", "external.in*", "standard-modules.in"),
        ("text/x-kconfig",),
    ),
    "KernelLogLexer": (
        "pip._vendor.pygments.lexers.textfmts",
        "Kernel log",
        ("kmsg", "dmesg"),
        ("*.kmsg", "*.dmesg"),
        (),
    ),
    "KokaLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Koka",
        ("koka",),
        ("*.kk", "*.kki"),
        ("text/x-koka",),
    ),
    "KotlinLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Kotlin",
        ("kotlin",),
        ("*.kt", "*.kts"),
        ("text/x-kotlin",),
    ),
    "KuinLexer": ("pip._vendor.pygments.lexers.kuin", "Kuin", ("kuin",), ("*.kn",), ()),
    "LSLLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "LSL",
        ("lsl",),
        ("*.lsl",),
        ("text/x-lsl",),
    ),
    "LassoCssLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Lasso",
        ("css+lasso",),
        (),
        ("text/css+lasso",),
    ),
    "LassoHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Lasso",
        ("html+lasso",),
        (),
        (
            "text/html+lasso",
            "application/x-httpd-lasso",
            "application/x-httpd-lasso[89]",
        ),
    ),
    "LassoJavascriptLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Lasso",
        ("javascript+lasso", "js+lasso"),
        (),
        (
            "application/x-javascript+lasso",
            "text/x-javascript+lasso",
            "text/javascript+lasso",
        ),
    ),
    "LassoLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Lasso",
        ("lasso", "lassoscript"),
        ("*.lasso", "*.lasso[89]"),
        ("text/x-lasso",),
    ),
    "LassoXmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Lasso",
        ("xml+lasso",),
        (),
        ("application/xml+lasso",),
    ),
    "LeanLexer": (
        "pip._vendor.pygments.lexers.theorem",
        "Lean",
        ("lean",),
        ("*.lean",),
        ("text/x-lean",),
    ),
    "LessCssLexer": (
        "pip._vendor.pygments.lexers.css",
        "LessCss",
        ("less",),
        ("*.less",),
        ("text/x-less-css",),
    ),
    "LighttpdConfLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Lighttpd configuration file",
        ("lighttpd", "lighty"),
        ("lighttpd.conf",),
        ("text/x-lighttpd-conf",),
    ),
    "LilyPondLexer": (
        "pip._vendor.pygments.lexers.lilypond",
        "LilyPond",
        ("lilypond",),
        ("*.ly",),
        (),
    ),
    "LimboLexer": (
        "pip._vendor.pygments.lexers.inferno",
        "Limbo",
        ("limbo",),
        ("*.b",),
        ("text/limbo",),
    ),
    "LiquidLexer": (
        "pip._vendor.pygments.lexers.templates",
        "liquid",
        ("liquid",),
        ("*.liquid",),
        (),
    ),
    "LiterateAgdaLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Literate Agda",
        ("literate-agda", "lagda"),
        ("*.lagda",),
        ("text/x-literate-agda",),
    ),
    "LiterateCryptolLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Literate Cryptol",
        ("literate-cryptol", "lcryptol", "lcry"),
        ("*.lcry",),
        ("text/x-literate-cryptol",),
    ),
    "LiterateHaskellLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Literate Haskell",
        ("literate-haskell", "lhaskell", "lhs"),
        ("*.lhs",),
        ("text/x-literate-haskell",),
    ),
    "LiterateIdrisLexer": (
        "pip._vendor.pygments.lexers.haskell",
        "Literate Idris",
        ("literate-idris", "lidris", "lidr"),
        ("*.lidr",),
        ("text/x-literate-idris",),
    ),
    "LiveScriptLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "LiveScript",
        ("livescript", "live-script"),
        ("*.ls",),
        ("text/livescript",),
    ),
    "LlvmLexer": (
        "pip._vendor.pygments.lexers.asm",
        "LLVM",
        ("llvm",),
        ("*.ll",),
        ("text/x-llvm",),
    ),
    "LlvmMirBodyLexer": (
        "pip._vendor.pygments.lexers.asm",
        "LLVM-MIR Body",
        ("llvm-mir-body",),
        (),
        (),
    ),
    "LlvmMirLexer": (
        "pip._vendor.pygments.lexers.asm",
        "LLVM-MIR",
        ("llvm-mir",),
        ("*.mir",),
        (),
    ),
    "LogosLexer": (
        "pip._vendor.pygments.lexers.objective",
        "Logos",
        ("logos",),
        ("*.x", "*.xi", "*.xm", "*.xmi"),
        ("text/x-logos",),
    ),
    "LogtalkLexer": (
        "pip._vendor.pygments.lexers.prolog",
        "Logtalk",
        ("logtalk",),
        ("*.lgt", "*.logtalk"),
        ("text/x-logtalk",),
    ),
    "LuaLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "Lua",
        ("lua",),
        ("*.lua", "*.wlua"),
        ("text/x-lua", "application/x-lua"),
    ),
    "MCFunctionLexer": (
        "pip._vendor.pygments.lexers.mcfunction",
        "MCFunction",
        ("mcfunction", "mcf"),
        ("*.mcfunction",),
        ("text/mcfunction",),
    ),
    "MIMELexer": (
        "pip._vendor.pygments.lexers.mime",
        "MIME",
        ("mime",),
        (),
        ("multipart/mixed", "multipart/related", "multipart/alternative"),
    ),
    "MOOCodeLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "MOOCode",
        ("moocode", "moo"),
        ("*.moo",),
        ("text/x-moocode",),
    ),
    "MSDOSSessionLexer": (
        "pip._vendor.pygments.lexers.shell",
        "MSDOS Session",
        ("doscon",),
        (),
        (),
    ),
    "Macaulay2Lexer": (
        "pip._vendor.pygments.lexers.macaulay2",
        "Macaulay2",
        ("macaulay2",),
        ("*.m2",),
        (),
    ),
    "MakefileLexer": (
        "pip._vendor.pygments.lexers.make",
        "Makefile",
        ("make", "makefile", "mf", "bsdmake"),
        ("*.mak", "*.mk", "Makefile", "makefile", "Makefile.*", "GNUmakefile"),
        ("text/x-makefile",),
    ),
    "MakoCssLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Mako",
        ("css+mako",),
        (),
        ("text/css+mako",),
    ),
    "MakoHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Mako",
        ("html+mako",),
        (),
        ("text/html+mako",),
    ),
    "MakoJavascriptLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Mako",
        ("javascript+mako", "js+mako"),
        (),
        (
            "application/x-javascript+mako",
            "text/x-javascript+mako",
            "text/javascript+mako",
        ),
    ),
    "MakoLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Mako",
        ("mako",),
        ("*.mao",),
        ("application/x-mako",),
    ),
    "MakoXmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Mako",
        ("xml+mako",),
        (),
        ("application/xml+mako",),
    ),
    "MaqlLexer": (
        "pip._vendor.pygments.lexers.business",
        "MAQL",
        ("maql",),
        ("*.maql",),
        ("text/x-gooddata-maql", "application/x-gooddata-maql"),
    ),
    "MarkdownLexer": (
        "pip._vendor.pygments.lexers.markup",
        "Markdown",
        ("markdown", "md"),
        ("*.md", "*.markdown"),
        ("text/x-markdown",),
    ),
    "MaskLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Mask",
        ("mask",),
        ("*.mask",),
        ("text/x-mask",),
    ),
    "MasonLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Mason",
        ("mason",),
        ("*.m", "*.mhtml", "*.mc", "*.mi", "autohandler", "dhandler"),
        ("application/x-mason",),
    ),
    "MathematicaLexer": (
        "pip._vendor.pygments.lexers.algebra",
        "Mathematica",
        ("mathematica", "mma", "nb"),
        ("*.nb", "*.cdf", "*.nbp", "*.ma"),
        (
            "application/mathematica",
            "application/vnd.wolfram.mathematica",
            "application/vnd.wolfram.mathematica.package",
            "application/vnd.wolfram.cdf",
        ),
    ),
    "MatlabLexer": (
        "pip._vendor.pygments.lexers.matlab",
        "Matlab",
        ("matlab",),
        ("*.m",),
        ("text/matlab",),
    ),
    "MatlabSessionLexer": (
        "pip._vendor.pygments.lexers.matlab",
        "Matlab session",
        ("matlabsession",),
        (),
        (),
    ),
    "MaximaLexer": (
        "pip._vendor.pygments.lexers.maxima",
        "Maxima",
        ("maxima", "macsyma"),
        ("*.mac", "*.max"),
        (),
    ),
    "MesonLexer": (
        "pip._vendor.pygments.lexers.meson",
        "Meson",
        ("meson", "meson.build"),
        ("meson.build", "meson_options.txt"),
        ("text/x-meson",),
    ),
    "MiniDLexer": (
        "pip._vendor.pygments.lexers.d",
        "MiniD",
        ("minid",),
        (),
        ("text/x-minidsrc",),
    ),
    "MiniScriptLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "MiniScript",
        ("miniscript", "ms"),
        ("*.ms",),
        ("text/x-minicript", "application/x-miniscript"),
    ),
    "ModelicaLexer": (
        "pip._vendor.pygments.lexers.modeling",
        "Modelica",
        ("modelica",),
        ("*.mo",),
        ("text/x-modelica",),
    ),
    "Modula2Lexer": (
        "pip._vendor.pygments.lexers.modula2",
        "Modula-2",
        ("modula2", "m2"),
        ("*.def", "*.mod"),
        ("text/x-modula2",),
    ),
    "MoinWikiLexer": (
        "pip._vendor.pygments.lexers.markup",
        "MoinMoin/Trac Wiki markup",
        ("trac-wiki", "moin"),
        (),
        ("text/x-trac-wiki",),
    ),
    "MonkeyLexer": (
        "pip._vendor.pygments.lexers.basic",
        "Monkey",
        ("monkey",),
        ("*.monkey",),
        ("text/x-monkey",),
    ),
    "MonteLexer": (
        "pip._vendor.pygments.lexers.monte",
        "Monte",
        ("monte",),
        ("*.mt",),
        (),
    ),
    "MoonScriptLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "MoonScript",
        ("moonscript", "moon"),
        ("*.moon",),
        ("text/x-moonscript", "application/x-moonscript"),
    ),
    "MoselLexer": (
        "pip._vendor.pygments.lexers.mosel",
        "Mosel",
        ("mosel",),
        ("*.mos",),
        (),
    ),
    "MozPreprocCssLexer": (
        "pip._vendor.pygments.lexers.markup",
        "CSS+mozpreproc",
        ("css+mozpreproc",),
        ("*.css.in",),
        (),
    ),
    "MozPreprocHashLexer": (
        "pip._vendor.pygments.lexers.markup",
        "mozhashpreproc",
        ("mozhashpreproc",),
        (),
        (),
    ),
    "MozPreprocJavascriptLexer": (
        "pip._vendor.pygments.lexers.markup",
        "Javascript+mozpreproc",
        ("javascript+mozpreproc",),
        ("*.js.in",),
        (),
    ),
    "MozPreprocPercentLexer": (
        "pip._vendor.pygments.lexers.markup",
        "mozpercentpreproc",
        ("mozpercentpreproc",),
        (),
        (),
    ),
    "MozPreprocXulLexer": (
        "pip._vendor.pygments.lexers.markup",
        "XUL+mozpreproc",
        ("xul+mozpreproc",),
        ("*.xul.in",),
        (),
    ),
    "MqlLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "MQL",
        ("mql", "mq4", "mq5", "mql4", "mql5"),
        ("*.mq4", "*.mq5", "*.mqh"),
        ("text/x-mql",),
    ),
    "MscgenLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Mscgen",
        ("mscgen", "msc"),
        ("*.msc",),
        (),
    ),
    "MuPADLexer": (
        "pip._vendor.pygments.lexers.algebra",
        "MuPAD",
        ("mupad",),
        ("*.mu",),
        (),
    ),
    "MxmlLexer": (
        "pip._vendor.pygments.lexers.actionscript",
        "MXML",
        ("mxml",),
        ("*.mxml",),
        (),
    ),
    "MySqlLexer": (
        "pip._vendor.pygments.lexers.sql",
        "MySQL",
        ("mysql",),
        (),
        ("text/x-mysql",),
    ),
    "MyghtyCssLexer": (
        "pip._vendor.pygments.lexers.templates",
        "CSS+Myghty",
        ("css+myghty",),
        (),
        ("text/css+myghty",),
    ),
    "MyghtyHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Myghty",
        ("html+myghty",),
        (),
        ("text/html+myghty",),
    ),
    "MyghtyJavascriptLexer": (
        "pip._vendor.pygments.lexers.templates",
        "JavaScript+Myghty",
        ("javascript+myghty", "js+myghty"),
        (),
        (
            "application/x-javascript+myghty",
            "text/x-javascript+myghty",
            "text/javascript+mygthy",
        ),
    ),
    "MyghtyLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Myghty",
        ("myghty",),
        ("*.myt", "autodelegate"),
        ("application/x-myghty",),
    ),
    "MyghtyXmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Myghty",
        ("xml+myghty",),
        (),
        ("application/xml+myghty",),
    ),
    "NCLLexer": (
        "pip._vendor.pygments.lexers.ncl",
        "NCL",
        ("ncl",),
        ("*.ncl",),
        ("text/ncl",),
    ),
    "NSISLexer": (
        "pip._vendor.pygments.lexers.installers",
        "NSIS",
        ("nsis", "nsi", "nsh"),
        ("*.nsi", "*.nsh"),
        ("text/x-nsis",),
    ),
    "NasmLexer": (
        "pip._vendor.pygments.lexers.asm",
        "NASM",
        ("nasm",),
        ("*.asm", "*.ASM"),
        ("text/x-nasm",),
    ),
    "NasmObjdumpLexer": (
        "pip._vendor.pygments.lexers.asm",
        "objdump-nasm",
        ("objdump-nasm",),
        ("*.objdump-intel",),
        ("text/x-nasm-objdump",),
    ),
    "NemerleLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "Nemerle",
        ("nemerle",),
        ("*.n",),
        ("text/x-nemerle",),
    ),
    "NesCLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "nesC",
        ("nesc",),
        ("*.nc",),
        ("text/x-nescsrc",),
    ),
    "NestedTextLexer": (
        "pip._vendor.pygments.lexers.configs",
        "NestedText",
        ("nestedtext", "nt"),
        ("*.nt",),
        (),
    ),
    "NewLispLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "NewLisp",
        ("newlisp",),
        ("*.lsp", "*.nl", "*.kif"),
        ("text/x-newlisp", "application/x-newlisp"),
    ),
    "NewspeakLexer": (
        "pip._vendor.pygments.lexers.smalltalk",
        "Newspeak",
        ("newspeak",),
        ("*.ns2",),
        ("text/x-newspeak",),
    ),
    "NginxConfLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Nginx configuration file",
        ("nginx",),
        ("nginx.conf",),
        ("text/x-nginx-conf",),
    ),
    "NimrodLexer": (
        "pip._vendor.pygments.lexers.nimrod",
        "Nimrod",
        ("nimrod", "nim"),
        ("*.nim", "*.nimrod"),
        ("text/x-nim",),
    ),
    "NitLexer": ("pip._vendor.pygments.lexers.nit", "Nit", ("nit",), ("*.nit",), ()),
    "NixLexer": (
        "pip._vendor.pygments.lexers.nix",
        "Nix",
        ("nixos", "nix"),
        ("*.nix",),
        ("text/x-nix",),
    ),
    "NodeConsoleLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Node.js REPL console session",
        ("nodejsrepl",),
        (),
        ("text/x-nodejsrepl",),
    ),
    "NotmuchLexer": (
        "pip._vendor.pygments.lexers.textfmts",
        "Notmuch",
        ("notmuch",),
        (),
        (),
    ),
    "NuSMVLexer": (
        "pip._vendor.pygments.lexers.smv",
        "NuSMV",
        ("nusmv",),
        ("*.smv",),
        (),
    ),
    "NumPyLexer": ("pip._vendor.pygments.lexers.python", "NumPy", ("numpy",), (), ()),
    "ObjdumpLexer": (
        "pip._vendor.pygments.lexers.asm",
        "objdump",
        ("objdump",),
        ("*.objdump",),
        ("text/x-objdump",),
    ),
    "ObjectiveCLexer": (
        "pip._vendor.pygments.lexers.objective",
        "Objective-C",
        ("objective-c", "objectivec", "obj-c", "objc"),
        ("*.m", "*.h"),
        ("text/x-objective-c",),
    ),
    "ObjectiveCppLexer": (
        "pip._vendor.pygments.lexers.objective",
        "Objective-C++",
        ("objective-c++", "objectivec++", "obj-c++", "objc++"),
        ("*.mm", "*.hh"),
        ("text/x-objective-c++",),
    ),
    "ObjectiveJLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "Objective-J",
        ("objective-j", "objectivej", "obj-j", "objj"),
        ("*.j",),
        ("text/x-objective-j",),
    ),
    "OcamlLexer": (
        "pip._vendor.pygments.lexers.ml",
        "OCaml",
        ("ocaml",),
        ("*.ml", "*.mli", "*.mll", "*.mly"),
        ("text/x-ocaml",),
    ),
    "OctaveLexer": (
        "pip._vendor.pygments.lexers.matlab",
        "Octave",
        ("octave",),
        ("*.m",),
        ("text/octave",),
    ),
    "OdinLexer": (
        "pip._vendor.pygments.lexers.archetype",
        "ODIN",
        ("odin",),
        ("*.odin",),
        ("text/odin",),
    ),
    "OmgIdlLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "OMG Interface Definition Language",
        ("omg-idl",),
        ("*.idl", "*.pidl"),
        (),
    ),
    "OocLexer": (
        "pip._vendor.pygments.lexers.ooc",
        "Ooc",
        ("ooc",),
        ("*.ooc",),
        ("text/x-ooc",),
    ),
    "OpaLexer": (
        "pip._vendor.pygments.lexers.ml",
        "Opa",
        ("opa",),
        ("*.opa",),
        ("text/x-opa",),
    ),
    "OpenEdgeLexer": (
        "pip._vendor.pygments.lexers.business",
        "OpenEdge ABL",
        ("openedge", "abl", "progress"),
        ("*.p", "*.cls"),
        ("text/x-openedge", "application/x-openedge"),
    ),
    "OutputLexer": (
        "pip._vendor.pygments.lexers.special",
        "Text output",
        ("output",),
        (),
        (),
    ),
    "PacmanConfLexer": (
        "pip._vendor.pygments.lexers.configs",
        "PacmanConf",
        ("pacmanconf",),
        ("pacman.conf",),
        (),
    ),
    "PanLexer": ("pip._vendor.pygments.lexers.dsls", "Pan", ("pan",), ("*.pan",), ()),
    "ParaSailLexer": (
        "pip._vendor.pygments.lexers.parasail",
        "ParaSail",
        ("parasail",),
        ("*.psi", "*.psl"),
        ("text/x-parasail",),
    ),
    "PawnLexer": (
        "pip._vendor.pygments.lexers.pawn",
        "Pawn",
        ("pawn",),
        ("*.p", "*.pwn", "*.inc"),
        ("text/x-pawn",),
    ),
    "PegLexer": (
        "pip._vendor.pygments.lexers.grammar_notation",
        "PEG",
        ("peg",),
        ("*.peg",),
        ("text/x-peg",),
    ),
    "Perl6Lexer": (
        "pip._vendor.pygments.lexers.perl",
        "Perl6",
        ("perl6", "pl6", "raku"),
        (
            "*.pl",
            "*.pm",
            "*.nqp",
            "*.p6",
            "*.6pl",
            "*.p6l",
            "*.pl6",
            "*.6pm",
            "*.p6m",
            "*.pm6",
            "*.t",
            "*.raku",
            "*.rakumod",
            "*.rakutest",
            "*.rakudoc",
        ),
        ("text/x-perl6", "application/x-perl6"),
    ),
    "PerlLexer": (
        "pip._vendor.pygments.lexers.perl",
        "Perl",
        ("perl", "pl"),
        ("*.pl", "*.pm", "*.t", "*.perl"),
        ("text/x-perl", "application/x-perl"),
    ),
    "PhpLexer": (
        "pip._vendor.pygments.lexers.php",
        "PHP",
        ("php", "php3", "php4", "php5"),
        ("*.php", "*.php[345]", "*.inc"),
        ("text/x-php",),
    ),
    "PigLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Pig",
        ("pig",),
        ("*.pig",),
        ("text/x-pig",),
    ),
    "PikeLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "Pike",
        ("pike",),
        ("*.pike", "*.pmod"),
        ("text/x-pike",),
    ),
    "PkgConfigLexer": (
        "pip._vendor.pygments.lexers.configs",
        "PkgConfig",
        ("pkgconfig",),
        ("*.pc",),
        (),
    ),
    "PlPgsqlLexer": (
        "pip._vendor.pygments.lexers.sql",
        "PL/pgSQL",
        ("plpgsql",),
        (),
        ("text/x-plpgsql",),
    ),
    "PointlessLexer": (
        "pip._vendor.pygments.lexers.pointless",
        "Pointless",
        ("pointless",),
        ("*.ptls",),
        (),
    ),
    "PonyLexer": (
        "pip._vendor.pygments.lexers.pony",
        "Pony",
        ("pony",),
        ("*.pony",),
        (),
    ),
    "PostScriptLexer": (
        "pip._vendor.pygments.lexers.graphics",
        "PostScript",
        ("postscript", "postscr"),
        ("*.ps", "*.eps"),
        ("application/postscript",),
    ),
    "PostgresConsoleLexer": (
        "pip._vendor.pygments.lexers.sql",
        "PostgreSQL console (psql)",
        ("psql", "postgresql-console", "postgres-console"),
        (),
        ("text/x-postgresql-psql",),
    ),
    "PostgresLexer": (
        "pip._vendor.pygments.lexers.sql",
        "PostgreSQL SQL dialect",
        ("postgresql", "postgres"),
        (),
        ("text/x-postgresql",),
    ),
    "PovrayLexer": (
        "pip._vendor.pygments.lexers.graphics",
        "POVRay",
        ("pov",),
        ("*.pov", "*.inc"),
        ("text/x-povray",),
    ),
    "PowerShellLexer": (
        "pip._vendor.pygments.lexers.shell",
        "PowerShell",
        ("powershell", "pwsh", "posh", "ps1", "psm1"),
        ("*.ps1", "*.psm1"),
        ("text/x-powershell",),
    ),
    "PowerShellSessionLexer": (
        "pip._vendor.pygments.lexers.shell",
        "PowerShell Session",
        ("pwsh-session", "ps1con"),
        (),
        (),
    ),
    "PraatLexer": (
        "pip._vendor.pygments.lexers.praat",
        "Praat",
        ("praat",),
        ("*.praat", "*.proc", "*.psc"),
        (),
    ),
    "ProcfileLexer": (
        "pip._vendor.pygments.lexers.procfile",
        "Procfile",
        ("procfile",),
        ("Procfile",),
        (),
    ),
    "PrologLexer": (
        "pip._vendor.pygments.lexers.prolog",
        "Prolog",
        ("prolog",),
        ("*.ecl", "*.prolog", "*.pro", "*.pl"),
        ("text/x-prolog",),
    ),
    "PromQLLexer": (
        "pip._vendor.pygments.lexers.promql",
        "PromQL",
        ("promql",),
        ("*.promql",),
        (),
    ),
    "PropertiesLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Properties",
        ("properties", "jproperties"),
        ("*.properties",),
        ("text/x-java-properties",),
    ),
    "ProtoBufLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Protocol Buffer",
        ("protobuf", "proto"),
        ("*.proto",),
        (),
    ),
    "PsyshConsoleLexer": (
        "pip._vendor.pygments.lexers.php",
        "PsySH console session for PHP",
        ("psysh",),
        (),
        (),
    ),
    "PugLexer": (
        "pip._vendor.pygments.lexers.html",
        "Pug",
        ("pug", "jade"),
        ("*.pug", "*.jade"),
        ("text/x-pug", "text/x-jade"),
    ),
    "PuppetLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Puppet",
        ("puppet",),
        ("*.pp",),
        (),
    ),
    "PyPyLogLexer": (
        "pip._vendor.pygments.lexers.console",
        "PyPy Log",
        ("pypylog", "pypy"),
        ("*.pypylog",),
        ("application/x-pypylog",),
    ),
    "Python2Lexer": (
        "pip._vendor.pygments.lexers.python",
        "Python 2.x",
        ("python2", "py2"),
        (),
        ("text/x-python2", "application/x-python2"),
    ),
    "Python2TracebackLexer": (
        "pip._vendor.pygments.lexers.python",
        "Python 2.x Traceback",
        ("py2tb",),
        ("*.py2tb",),
        ("text/x-python2-traceback",),
    ),
    "PythonConsoleLexer": (
        "pip._vendor.pygments.lexers.python",
        "Python console session",
        ("pycon",),
        (),
        ("text/x-python-doctest",),
    ),
    "PythonLexer": (
        "pip._vendor.pygments.lexers.python",
        "Python",
        ("python", "py", "sage", "python3", "py3"),
        (
            "*.py",
            "*.pyw",
            "*.jy",
            "*.sage",
            "*.sc",
            "SConstruct",
            "SConscript",
            "*.bzl",
            "BUCK",
            "BUILD",
            "BUILD.bazel",
            "WORKSPACE",
            "*.tac",
        ),
        (
            "text/x-python",
            "application/x-python",
            "text/x-python3",
            "application/x-python3",
        ),
    ),
    "PythonTracebackLexer": (
        "pip._vendor.pygments.lexers.python",
        "Python Traceback",
        ("pytb", "py3tb"),
        ("*.pytb", "*.py3tb"),
        ("text/x-python-traceback", "text/x-python3-traceback"),
    ),
    "PythonUL4Lexer": (
        "pip._vendor.pygments.lexers.ul4",
        "Python+UL4",
        ("py+ul4",),
        ("*.pyul4",),
        (),
    ),
    "QBasicLexer": (
        "pip._vendor.pygments.lexers.basic",
        "QBasic",
        ("qbasic", "basic"),
        ("*.BAS", "*.bas"),
        ("text/basic",),
    ),
    "QLexer": ("pip._vendor.pygments.lexers.q", "Q", ("q",), ("*.q",), ()),
    "QVToLexer": (
        "pip._vendor.pygments.lexers.qvt",
        "QVTO",
        ("qvto", "qvt"),
        ("*.qvto",),
        (),
    ),
    "QlikLexer": (
        "pip._vendor.pygments.lexers.qlik",
        "Qlik",
        ("qlik", "qlikview", "qliksense", "qlikscript"),
        ("*.qvs", "*.qvw"),
        (),
    ),
    "QmlLexer": (
        "pip._vendor.pygments.lexers.webmisc",
        "QML",
        ("qml", "qbs"),
        ("*.qml", "*.qbs"),
        ("application/x-qml", "application/x-qt.qbs+qml"),
    ),
    "RConsoleLexer": (
        "pip._vendor.pygments.lexers.r",
        "RConsole",
        ("rconsole", "rout"),
        ("*.Rout",),
        (),
    ),
    "RNCCompactLexer": (
        "pip._vendor.pygments.lexers.rnc",
        "Relax-NG Compact",
        ("rng-compact", "rnc"),
        ("*.rnc",),
        (),
    ),
    "RPMSpecLexer": (
        "pip._vendor.pygments.lexers.installers",
        "RPMSpec",
        ("spec",),
        ("*.spec",),
        ("text/x-rpm-spec",),
    ),
    "RacketLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "Racket",
        ("racket", "rkt"),
        ("*.rkt", "*.rktd", "*.rktl"),
        ("text/x-racket", "application/x-racket"),
    ),
    "RagelCLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Ragel in C Host",
        ("ragel-c",),
        ("*.rl",),
        (),
    ),
    "RagelCppLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Ragel in CPP Host",
        ("ragel-cpp",),
        ("*.rl",),
        (),
    ),
    "RagelDLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Ragel in D Host",
        ("ragel-d",),
        ("*.rl",),
        (),
    ),
    "RagelEmbeddedLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Embedded Ragel",
        ("ragel-em",),
        ("*.rl",),
        (),
    ),
    "RagelJavaLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Ragel in Java Host",
        ("ragel-java",),
        ("*.rl",),
        (),
    ),
    "RagelLexer": ("pip._vendor.pygments.lexers.parsers", "Ragel", ("ragel",), (), ()),
    "RagelObjectiveCLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Ragel in Objective C Host",
        ("ragel-objc",),
        ("*.rl",),
        (),
    ),
    "RagelRubyLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Ragel in Ruby Host",
        ("ragel-ruby", "ragel-rb"),
        ("*.rl",),
        (),
    ),
    "RawTokenLexer": (
        "pip._vendor.pygments.lexers.special",
        "Raw token data",
        (),
        (),
        ("application/x-pygments-tokens",),
    ),
    "RdLexer": (
        "pip._vendor.pygments.lexers.r",
        "Rd",
        ("rd",),
        ("*.Rd",),
        ("text/x-r-doc",),
    ),
    "ReasonLexer": (
        "pip._vendor.pygments.lexers.ml",
        "ReasonML",
        ("reasonml", "reason"),
        ("*.re", "*.rei"),
        ("text/x-reasonml",),
    ),
    "RebolLexer": (
        "pip._vendor.pygments.lexers.rebol",
        "REBOL",
        ("rebol",),
        ("*.r", "*.r3", "*.reb"),
        ("text/x-rebol",),
    ),
    "RedLexer": (
        "pip._vendor.pygments.lexers.rebol",
        "Red",
        ("red", "red/system"),
        ("*.red", "*.reds"),
        ("text/x-red", "text/x-red-system"),
    ),
    "RedcodeLexer": (
        "pip._vendor.pygments.lexers.esoteric",
        "Redcode",
        ("redcode",),
        ("*.cw",),
        (),
    ),
    "RegeditLexer": (
        "pip._vendor.pygments.lexers.configs",
        "reg",
        ("registry",),
        ("*.reg",),
        ("text/x-windows-registry",),
    ),
    "ResourceLexer": (
        "pip._vendor.pygments.lexers.resource",
        "ResourceBundle",
        ("resourcebundle", "resource"),
        (),
        (),
    ),
    "RexxLexer": (
        "pip._vendor.pygments.lexers.scripting",
        "Rexx",
        ("rexx", "arexx"),
        ("*.rexx", "*.rex", "*.rx", "*.arexx"),
        ("text/x-rexx",),
    ),
    "RhtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "RHTML",
        ("rhtml", "html+erb", "html+ruby"),
        ("*.rhtml",),
        ("text/html+ruby",),
    ),
    "RideLexer": (
        "pip._vendor.pygments.lexers.ride",
        "Ride",
        ("ride",),
        ("*.ride",),
        ("text/x-ride",),
    ),
    "RitaLexer": (
        "pip._vendor.pygments.lexers.rita",
        "Rita",
        ("rita",),
        ("*.rita",),
        ("text/rita",),
    ),
    "RoboconfGraphLexer": (
        "pip._vendor.pygments.lexers.roboconf",
        "Roboconf Graph",
        ("roboconf-graph",),
        ("*.graph",),
        (),
    ),
    "RoboconfInstancesLexer": (
        "pip._vendor.pygments.lexers.roboconf",
        "Roboconf Instances",
        ("roboconf-instances",),
        ("*.instances",),
        (),
    ),
    "RobotFrameworkLexer": (
        "pip._vendor.pygments.lexers.robotframework",
        "RobotFramework",
        ("robotframework",),
        ("*.robot", "*.resource"),
        ("text/x-robotframework",),
    ),
    "RqlLexer": (
        "pip._vendor.pygments.lexers.sql",
        "RQL",
        ("rql",),
        ("*.rql",),
        ("text/x-rql",),
    ),
    "RslLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "RSL",
        ("rsl",),
        ("*.rsl",),
        ("text/rsl",),
    ),
    "RstLexer": (
        "pip._vendor.pygments.lexers.markup",
        "reStructuredText",
        ("restructuredtext", "rst", "rest"),
        ("*.rst", "*.rest"),
        ("text/x-rst", "text/prs.fallenstein.rst"),
    ),
    "RtsLexer": (
        "pip._vendor.pygments.lexers.trafficscript",
        "TrafficScript",
        ("trafficscript", "rts"),
        ("*.rts",),
        (),
    ),
    "RubyConsoleLexer": (
        "pip._vendor.pygments.lexers.ruby",
        "Ruby irb session",
        ("rbcon", "irb"),
        (),
        ("text/x-ruby-shellsession",),
    ),
    "RubyLexer": (
        "pip._vendor.pygments.lexers.ruby",
        "Ruby",
        ("ruby", "rb", "duby"),
        (
            "*.rb",
            "*.rbw",
            "Rakefile",
            "*.rake",
            "*.gemspec",
            "*.rbx",
            "*.duby",
            "Gemfile",
            "Vagrantfile",
        ),
        ("text/x-ruby", "application/x-ruby"),
    ),
    "RustLexer": (
        "pip._vendor.pygments.lexers.rust",
        "Rust",
        ("rust", "rs"),
        ("*.rs", "*.rs.in"),
        ("text/rust", "text/x-rust"),
    ),
    "SASLexer": (
        "pip._vendor.pygments.lexers.sas",
        "SAS",
        ("sas",),
        ("*.SAS", "*.sas"),
        ("text/x-sas", "text/sas", "application/x-sas"),
    ),
    "SLexer": (
        "pip._vendor.pygments.lexers.r",
        "S",
        ("splus", "s", "r"),
        ("*.S", "*.R", ".Rhistory", ".Rprofile", ".Renviron"),
        (
            "text/S-plus",
            "text/S",
            "text/x-r-source",
            "text/x-r",
            "text/x-R",
            "text/x-r-history",
            "text/x-r-profile",
        ),
    ),
    "SMLLexer": (
        "pip._vendor.pygments.lexers.ml",
        "Standard ML",
        ("sml",),
        ("*.sml", "*.sig", "*.fun"),
        ("text/x-standardml", "application/x-standardml"),
    ),
    "SNBTLexer": (
        "pip._vendor.pygments.lexers.mcfunction",
        "SNBT",
        ("snbt",),
        ("*.snbt",),
        ("text/snbt",),
    ),
    "SarlLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "SARL",
        ("sarl",),
        ("*.sarl",),
        ("text/x-sarl",),
    ),
    "SassLexer": (
        "pip._vendor.pygments.lexers.css",
        "Sass",
        ("sass",),
        ("*.sass",),
        ("text/x-sass",),
    ),
    "SaviLexer": (
        "pip._vendor.pygments.lexers.savi",
        "Savi",
        ("savi",),
        ("*.savi",),
        (),
    ),
    "ScalaLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Scala",
        ("scala",),
        ("*.scala",),
        ("text/x-scala",),
    ),
    "ScamlLexer": (
        "pip._vendor.pygments.lexers.html",
        "Scaml",
        ("scaml",),
        ("*.scaml",),
        ("text/x-scaml",),
    ),
    "ScdocLexer": (
        "pip._vendor.pygments.lexers.scdoc",
        "scdoc",
        ("scdoc", "scd"),
        ("*.scd", "*.scdoc"),
        (),
    ),
    "SchemeLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "Scheme",
        ("scheme", "scm"),
        ("*.scm", "*.ss"),
        ("text/x-scheme", "application/x-scheme"),
    ),
    "ScilabLexer": (
        "pip._vendor.pygments.lexers.matlab",
        "Scilab",
        ("scilab",),
        ("*.sci", "*.sce", "*.tst"),
        ("text/scilab",),
    ),
    "ScssLexer": (
        "pip._vendor.pygments.lexers.css",
        "SCSS",
        ("scss",),
        ("*.scss",),
        ("text/x-scss",),
    ),
    "SedLexer": (
        "pip._vendor.pygments.lexers.textedit",
        "Sed",
        ("sed", "gsed", "ssed"),
        ("*.sed", "*.[gs]sed"),
        ("text/x-sed",),
    ),
    "ShExCLexer": (
        "pip._vendor.pygments.lexers.rdf",
        "ShExC",
        ("shexc", "shex"),
        ("*.shex",),
        ("text/shex",),
    ),
    "ShenLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "Shen",
        ("shen",),
        ("*.shen",),
        ("text/x-shen", "application/x-shen"),
    ),
    "SieveLexer": (
        "pip._vendor.pygments.lexers.sieve",
        "Sieve",
        ("sieve",),
        ("*.siv", "*.sieve"),
        (),
    ),
    "SilverLexer": (
        "pip._vendor.pygments.lexers.verification",
        "Silver",
        ("silver",),
        ("*.sil", "*.vpr"),
        (),
    ),
    "SingularityLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Singularity",
        ("singularity",),
        ("*.def", "Singularity"),
        (),
    ),
    "SlashLexer": (
        "pip._vendor.pygments.lexers.slash",
        "Slash",
        ("slash",),
        ("*.sla",),
        (),
    ),
    "SlimLexer": (
        "pip._vendor.pygments.lexers.webmisc",
        "Slim",
        ("slim",),
        ("*.slim",),
        ("text/x-slim",),
    ),
    "SlurmBashLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Slurm",
        ("slurm", "sbatch"),
        ("*.sl",),
        (),
    ),
    "SmaliLexer": (
        "pip._vendor.pygments.lexers.dalvik",
        "Smali",
        ("smali",),
        ("*.smali",),
        ("text/smali",),
    ),
    "SmalltalkLexer": (
        "pip._vendor.pygments.lexers.smalltalk",
        "Smalltalk",
        ("smalltalk", "squeak", "st"),
        ("*.st",),
        ("text/x-smalltalk",),
    ),
    "SmartGameFormatLexer": (
        "pip._vendor.pygments.lexers.sgf",
        "SmartGameFormat",
        ("sgf",),
        ("*.sgf",),
        (),
    ),
    "SmartyLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Smarty",
        ("smarty",),
        ("*.tpl",),
        ("application/x-smarty",),
    ),
    "SmithyLexer": (
        "pip._vendor.pygments.lexers.smithy",
        "Smithy",
        ("smithy",),
        ("*.smithy",),
        (),
    ),
    "SnobolLexer": (
        "pip._vendor.pygments.lexers.snobol",
        "Snobol",
        ("snobol",),
        ("*.snobol",),
        ("text/x-snobol",),
    ),
    "SnowballLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Snowball",
        ("snowball",),
        ("*.sbl",),
        (),
    ),
    "SolidityLexer": (
        "pip._vendor.pygments.lexers.solidity",
        "Solidity",
        ("solidity",),
        ("*.sol",),
        (),
    ),
    "SophiaLexer": (
        "pip._vendor.pygments.lexers.sophia",
        "Sophia",
        ("sophia",),
        ("*.aes",),
        (),
    ),
    "SourcePawnLexer": (
        "pip._vendor.pygments.lexers.pawn",
        "SourcePawn",
        ("sp",),
        ("*.sp",),
        ("text/x-sourcepawn",),
    ),
    "SourcesListLexer": (
        "pip._vendor.pygments.lexers.installers",
        "Debian Sourcelist",
        ("debsources", "sourceslist", "sources.list"),
        ("sources.list",),
        (),
    ),
    "SparqlLexer": (
        "pip._vendor.pygments.lexers.rdf",
        "SPARQL",
        ("sparql",),
        ("*.rq", "*.sparql"),
        ("application/sparql-query",),
    ),
    "SpiceLexer": (
        "pip._vendor.pygments.lexers.spice",
        "Spice",
        ("spice", "spicelang"),
        ("*.spice",),
        ("text/x-spice",),
    ),
    "SqlJinjaLexer": (
        "pip._vendor.pygments.lexers.templates",
        "SQL+Jinja",
        ("sql+jinja",),
        ("*.sql", "*.sql.j2", "*.sql.jinja2"),
        (),
    ),
    "SqlLexer": (
        "pip._vendor.pygments.lexers.sql",
        "SQL",
        ("sql",),
        ("*.sql",),
        ("text/x-sql",),
    ),
    "SqliteConsoleLexer": (
        "pip._vendor.pygments.lexers.sql",
        "sqlite3con",
        ("sqlite3",),
        ("*.sqlite3-console",),
        ("text/x-sqlite3-console",),
    ),
    "SquidConfLexer": (
        "pip._vendor.pygments.lexers.configs",
        "SquidConf",
        ("squidconf", "squid.conf", "squid"),
        ("squid.conf",),
        ("text/x-squidconf",),
    ),
    "SrcinfoLexer": (
        "pip._vendor.pygments.lexers.srcinfo",
        "Srcinfo",
        ("srcinfo",),
        (".SRCINFO",),
        (),
    ),
    "SspLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Scalate Server Page",
        ("ssp",),
        ("*.ssp",),
        ("application/x-ssp",),
    ),
    "StanLexer": (
        "pip._vendor.pygments.lexers.modeling",
        "Stan",
        ("stan",),
        ("*.stan",),
        (),
    ),
    "StataLexer": (
        "pip._vendor.pygments.lexers.stata",
        "Stata",
        ("stata", "do"),
        ("*.do", "*.ado"),
        ("text/x-stata", "text/stata", "application/x-stata"),
    ),
    "SuperColliderLexer": (
        "pip._vendor.pygments.lexers.supercollider",
        "SuperCollider",
        ("supercollider", "sc"),
        ("*.sc", "*.scd"),
        ("application/supercollider", "text/supercollider"),
    ),
    "SwiftLexer": (
        "pip._vendor.pygments.lexers.objective",
        "Swift",
        ("swift",),
        ("*.swift",),
        ("text/x-swift",),
    ),
    "SwigLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "SWIG",
        ("swig",),
        ("*.swg", "*.i"),
        ("text/swig",),
    ),
    "SystemVerilogLexer": (
        "pip._vendor.pygments.lexers.hdl",
        "systemverilog",
        ("systemverilog", "sv"),
        ("*.sv", "*.svh"),
        ("text/x-systemverilog",),
    ),
    "TAPLexer": (
        "pip._vendor.pygments.lexers.testing",
        "TAP",
        ("tap",),
        ("*.tap",),
        (),
    ),
    "TNTLexer": (
        "pip._vendor.pygments.lexers.tnt",
        "Typographic Number Theory",
        ("tnt",),
        ("*.tnt",),
        (),
    ),
    "TOMLLexer": (
        "pip._vendor.pygments.lexers.configs",
        "TOML",
        ("toml",),
        ("*.toml", "Pipfile", "poetry.lock"),
        (),
    ),
    "Tads3Lexer": (
        "pip._vendor.pygments.lexers.int_fiction",
        "TADS 3",
        ("tads3",),
        ("*.t",),
        (),
    ),
    "TalLexer": (
        "pip._vendor.pygments.lexers.tal",
        "Tal",
        ("tal", "uxntal"),
        ("*.tal",),
        ("text/x-uxntal",),
    ),
    "TasmLexer": (
        "pip._vendor.pygments.lexers.asm",
        "TASM",
        ("tasm",),
        ("*.asm", "*.ASM", "*.tasm"),
        ("text/x-tasm",),
    ),
    "TclLexer": (
        "pip._vendor.pygments.lexers.tcl",
        "Tcl",
        ("tcl",),
        ("*.tcl", "*.rvt"),
        ("text/x-tcl", "text/x-script.tcl", "application/x-tcl"),
    ),
    "TcshLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Tcsh",
        ("tcsh", "csh"),
        ("*.tcsh", "*.csh"),
        ("application/x-csh",),
    ),
    "TcshSessionLexer": (
        "pip._vendor.pygments.lexers.shell",
        "Tcsh Session",
        ("tcshcon",),
        (),
        (),
    ),
    "TeaTemplateLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Tea",
        ("tea",),
        ("*.tea",),
        ("text/x-tea",),
    ),
    "TealLexer": (
        "pip._vendor.pygments.lexers.teal",
        "teal",
        ("teal",),
        ("*.teal",),
        (),
    ),
    "TeraTermLexer": (
        "pip._vendor.pygments.lexers.teraterm",
        "Tera Term macro",
        ("teratermmacro", "teraterm", "ttl"),
        ("*.ttl",),
        ("text/x-teratermmacro",),
    ),
    "TermcapLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Termcap",
        ("termcap",),
        ("termcap", "termcap.src"),
        (),
    ),
    "TerminfoLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Terminfo",
        ("terminfo",),
        ("terminfo", "terminfo.src"),
        (),
    ),
    "TerraformLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Terraform",
        ("terraform", "tf"),
        ("*.tf",),
        ("application/x-tf", "application/x-terraform"),
    ),
    "TexLexer": (
        "pip._vendor.pygments.lexers.markup",
        "TeX",
        ("tex", "latex"),
        ("*.tex", "*.aux", "*.toc"),
        ("text/x-tex", "text/x-latex"),
    ),
    "TextLexer": (
        "pip._vendor.pygments.lexers.special",
        "Text only",
        ("text",),
        ("*.txt",),
        ("text/plain",),
    ),
    "ThingsDBLexer": (
        "pip._vendor.pygments.lexers.thingsdb",
        "ThingsDB",
        ("ti", "thingsdb"),
        ("*.ti",),
        (),
    ),
    "ThriftLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Thrift",
        ("thrift",),
        ("*.thrift",),
        ("application/x-thrift",),
    ),
    "TiddlyWiki5Lexer": (
        "pip._vendor.pygments.lexers.markup",
        "tiddler",
        ("tid",),
        ("*.tid",),
        ("text/vnd.tiddlywiki",),
    ),
    "TodotxtLexer": (
        "pip._vendor.pygments.lexers.textfmts",
        "Todotxt",
        ("todotxt",),
        ("todo.txt", "*.todotxt"),
        ("text/x-todo",),
    ),
    "TransactSqlLexer": (
        "pip._vendor.pygments.lexers.sql",
        "Transact-SQL",
        ("tsql", "t-sql"),
        ("*.sql",),
        ("text/x-tsql",),
    ),
    "TreetopLexer": (
        "pip._vendor.pygments.lexers.parsers",
        "Treetop",
        ("treetop",),
        ("*.treetop", "*.tt"),
        (),
    ),
    "TurtleLexer": (
        "pip._vendor.pygments.lexers.rdf",
        "Turtle",
        ("turtle",),
        ("*.ttl",),
        ("text/turtle", "application/x-turtle"),
    ),
    "TwigHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Twig",
        ("html+twig",),
        ("*.twig",),
        ("text/html+twig",),
    ),
    "TwigLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Twig",
        ("twig",),
        (),
        ("application/x-twig",),
    ),
    "TypeScriptLexer": (
        "pip._vendor.pygments.lexers.javascript",
        "TypeScript",
        ("typescript", "ts"),
        ("*.ts",),
        ("application/x-typescript", "text/x-typescript"),
    ),
    "TypoScriptCssDataLexer": (
        "pip._vendor.pygments.lexers.typoscript",
        "TypoScriptCssData",
        ("typoscriptcssdata",),
        (),
        (),
    ),
    "TypoScriptHtmlDataLexer": (
        "pip._vendor.pygments.lexers.typoscript",
        "TypoScriptHtmlData",
        ("typoscripthtmldata",),
        (),
        (),
    ),
    "TypoScriptLexer": (
        "pip._vendor.pygments.lexers.typoscript",
        "TypoScript",
        ("typoscript",),
        ("*.typoscript",),
        ("text/x-typoscript",),
    ),
    "UL4Lexer": ("pip._vendor.pygments.lexers.ul4", "UL4", ("ul4",), ("*.ul4",), ()),
    "UcodeLexer": (
        "pip._vendor.pygments.lexers.unicon",
        "ucode",
        ("ucode",),
        ("*.u", "*.u1", "*.u2"),
        (),
    ),
    "UniconLexer": (
        "pip._vendor.pygments.lexers.unicon",
        "Unicon",
        ("unicon",),
        ("*.icn",),
        ("text/unicon",),
    ),
    "UnixConfigLexer": (
        "pip._vendor.pygments.lexers.configs",
        "Unix/Linux config files",
        ("unixconfig", "linuxconfig"),
        (),
        (),
    ),
    "UrbiscriptLexer": (
        "pip._vendor.pygments.lexers.urbi",
        "UrbiScript",
        ("urbiscript",),
        ("*.u",),
        ("application/x-urbiscript",),
    ),
    "UsdLexer": (
        "pip._vendor.pygments.lexers.usd",
        "USD",
        ("usd", "usda"),
        ("*.usd", "*.usda"),
        (),
    ),
    "VBScriptLexer": (
        "pip._vendor.pygments.lexers.basic",
        "VBScript",
        ("vbscript",),
        ("*.vbs", "*.VBS"),
        (),
    ),
    "VCLLexer": (
        "pip._vendor.pygments.lexers.varnish",
        "VCL",
        ("vcl",),
        ("*.vcl",),
        ("text/x-vclsrc",),
    ),
    "VCLSnippetLexer": (
        "pip._vendor.pygments.lexers.varnish",
        "VCLSnippets",
        ("vclsnippets", "vclsnippet"),
        (),
        ("text/x-vclsnippet",),
    ),
    "VCTreeStatusLexer": (
        "pip._vendor.pygments.lexers.console",
        "VCTreeStatus",
        ("vctreestatus",),
        (),
        (),
    ),
    "VGLLexer": ("pip._vendor.pygments.lexers.dsls", "VGL", ("vgl",), ("*.rpf",), ()),
    "ValaLexer": (
        "pip._vendor.pygments.lexers.c_like",
        "Vala",
        ("vala", "vapi"),
        ("*.vala", "*.vapi"),
        ("text/x-vala",),
    ),
    "VbNetAspxLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "aspx-vb",
        ("aspx-vb",),
        ("*.aspx", "*.asax", "*.ascx", "*.ashx", "*.asmx", "*.axd"),
        (),
    ),
    "VbNetLexer": (
        "pip._vendor.pygments.lexers.dotnet",
        "VB.net",
        ("vb.net", "vbnet", "lobas", "oobas", "sobas"),
        ("*.vb", "*.bas"),
        ("text/x-vbnet", "text/x-vba"),
    ),
    "VelocityHtmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "HTML+Velocity",
        ("html+velocity",),
        (),
        ("text/html+velocity",),
    ),
    "VelocityLexer": (
        "pip._vendor.pygments.lexers.templates",
        "Velocity",
        ("velocity",),
        ("*.vm", "*.fhtml"),
        (),
    ),
    "VelocityXmlLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Velocity",
        ("xml+velocity",),
        (),
        ("application/xml+velocity",),
    ),
    "VerilogLexer": (
        "pip._vendor.pygments.lexers.hdl",
        "verilog",
        ("verilog", "v"),
        ("*.v",),
        ("text/x-verilog",),
    ),
    "VhdlLexer": (
        "pip._vendor.pygments.lexers.hdl",
        "vhdl",
        ("vhdl",),
        ("*.vhdl", "*.vhd"),
        ("text/x-vhdl",),
    ),
    "VimLexer": (
        "pip._vendor.pygments.lexers.textedit",
        "VimL",
        ("vim",),
        (
            "*.vim",
            ".vimrc",
            ".exrc",
            ".gvimrc",
            "_vimrc",
            "_exrc",
            "_gvimrc",
            "vimrc",
            "gvimrc",
        ),
        ("text/x-vim",),
    ),
    "WDiffLexer": (
        "pip._vendor.pygments.lexers.diff",
        "WDiff",
        ("wdiff",),
        ("*.wdiff",),
        (),
    ),
    "WatLexer": (
        "pip._vendor.pygments.lexers.webassembly",
        "WebAssembly",
        ("wast", "wat"),
        ("*.wat", "*.wast"),
        (),
    ),
    "WebIDLLexer": (
        "pip._vendor.pygments.lexers.webidl",
        "Web IDL",
        ("webidl",),
        ("*.webidl",),
        (),
    ),
    "WhileyLexer": (
        "pip._vendor.pygments.lexers.whiley",
        "Whiley",
        ("whiley",),
        ("*.whiley",),
        ("text/x-whiley",),
    ),
    "X10Lexer": (
        "pip._vendor.pygments.lexers.x10",
        "X10",
        ("x10", "xten"),
        ("*.x10",),
        ("text/x-x10",),
    ),
    "XMLUL4Lexer": (
        "pip._vendor.pygments.lexers.ul4",
        "XML+UL4",
        ("xml+ul4",),
        ("*.xmlul4",),
        (),
    ),
    "XQueryLexer": (
        "pip._vendor.pygments.lexers.webmisc",
        "XQuery",
        ("xquery", "xqy", "xq", "xql", "xqm"),
        ("*.xqy", "*.xquery", "*.xq", "*.xql", "*.xqm"),
        ("text/xquery", "application/xquery"),
    ),
    "XmlDjangoLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Django/Jinja",
        ("xml+django", "xml+jinja"),
        ("*.xml.j2", "*.xml.jinja2"),
        ("application/xml+django", "application/xml+jinja"),
    ),
    "XmlErbLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Ruby",
        ("xml+ruby", "xml+erb"),
        (),
        ("application/xml+ruby",),
    ),
    "XmlLexer": (
        "pip._vendor.pygments.lexers.html",
        "XML",
        ("xml",),
        ("*.xml", "*.xsl", "*.rss", "*.xslt", "*.xsd", "*.wsdl", "*.wsf"),
        (
            "text/xml",
            "application/xml",
            "image/svg+xml",
            "application/rss+xml",
            "application/atom+xml",
        ),
    ),
    "XmlPhpLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+PHP",
        ("xml+php",),
        (),
        ("application/xml+php",),
    ),
    "XmlSmartyLexer": (
        "pip._vendor.pygments.lexers.templates",
        "XML+Smarty",
        ("xml+smarty",),
        (),
        ("application/xml+smarty",),
    ),
    "XorgLexer": (
        "pip._vendor.pygments.lexers.xorg",
        "Xorg",
        ("xorg.conf",),
        ("xorg.conf",),
        (),
    ),
    "XsltLexer": (
        "pip._vendor.pygments.lexers.html",
        "XSLT",
        ("xslt",),
        ("*.xsl", "*.xslt", "*.xpl"),
        ("application/xsl+xml", "application/xslt+xml"),
    ),
    "XtendLexer": (
        "pip._vendor.pygments.lexers.jvm",
        "Xtend",
        ("xtend",),
        ("*.xtend",),
        ("text/x-xtend",),
    ),
    "XtlangLexer": (
        "pip._vendor.pygments.lexers.lisp",
        "xtlang",
        ("extempore",),
        ("*.xtm",),
        (),
    ),
    "YamlJinjaLexer": (
        "pip._vendor.pygments.lexers.templates",
        "YAML+Jinja",
        ("yaml+jinja", "salt", "sls"),
        ("*.sls", "*.yaml.j2", "*.yml.j2", "*.yaml.jinja2", "*.yml.jinja2"),
        ("text/x-yaml+jinja", "text/x-sls"),
    ),
    "YamlLexer": (
        "pip._vendor.pygments.lexers.data",
        "YAML",
        ("yaml",),
        ("*.yaml", "*.yml"),
        ("text/x-yaml",),
    ),
    "YangLexer": (
        "pip._vendor.pygments.lexers.yang",
        "YANG",
        ("yang",),
        ("*.yang",),
        ("application/yang",),
    ),
    "ZeekLexer": (
        "pip._vendor.pygments.lexers.dsls",
        "Zeek",
        ("zeek", "bro"),
        ("*.zeek", "*.bro"),
        (),
    ),
    "ZephirLexer": (
        "pip._vendor.pygments.lexers.php",
        "Zephir",
        ("zephir",),
        ("*.zep",),
        (),
    ),
    "ZigLexer": (
        "pip._vendor.pygments.lexers.zig",
        "Zig",
        ("zig",),
        ("*.zig",),
        ("text/zig",),
    ),
    "apdlexer": (
        "pip._vendor.pygments.lexers.apdlexer",
        "ANSYS parametric design language",
        ("ansys", "apdl"),
        ("*.ans",),
        (),
    ),
}



"""
    pygments.formatters.img
    ~~~~~~~~~~~~~~~~~~~~~~~

    Formatter for Pixmap output.

    :copyright: Copyright 2006-2022 by the Pygments team, see AUTHORS.
    :license: BSD, see LICENSE for details.
"""

import os
import sys

from pip._vendor.pygments.formatter import Formatter
from pip._vendor.pygments.util import (
    get_bool_opt,
    get_int_opt,
    get_list_opt,
    get_choice_opt,
)

import subprocess

# Import this carefully
try:
    from PIL import Image, ImageDraw, ImageFont

    pil_available = True
except ImportError:
    pil_available = False

try:
    import _winreg
except ImportError:
    try:
        import winreg as _winreg
    except ImportError:
        _winreg = None

__all__ = [
    "ImageFormatter",
    "GifImageFormatter",
    "JpgImageFormatter",
    "BmpImageFormatter",
]


# For some unknown reason every font calls it something different
STYLES = {
    "NORMAL": ["", "Roman", "Book", "Normal", "Regular", "Medium"],
    "ITALIC": ["Oblique", "Italic"],
    "BOLD": ["Bold"],
    "BOLDITALIC": ["Bold Oblique", "Bold Italic"],
}

# A sane default for modern systems
DEFAULT_FONT_NAME_NIX = "DejaVu Sans Mono"
DEFAULT_FONT_NAME_WIN = "Courier New"
DEFAULT_FONT_NAME_MAC = "Menlo"


class PilNotAvailable(ImportError):
    """When Python imaging library is not available"""


class FontNotFound(Exception):
    """When there are no usable fonts specified"""


class FontManager:
    """
    Manages a set of fonts: normal, italic, bold, etc...
    """

    def __init__(self, font_name, font_size=14):
        self.font_name = font_name
        self.font_size = font_size
        self.fonts = {}
        self.encoding = None
        if sys.platform.startswith("win"):
            if not font_name:
                self.font_name = DEFAULT_FONT_NAME_WIN
            self._create_win()
        elif sys.platform.startswith("darwin"):
            if not font_name:
                self.font_name = DEFAULT_FONT_NAME_MAC
            self._create_mac()
        else:
            if not font_name:
                self.font_name = DEFAULT_FONT_NAME_NIX
            self._create_nix()

    def _get_nix_font_path(self, name, style):
        proc = subprocess.Popen(
            ["fc-list", "%s:style=%s" % (name, style), "file"],
            stdout=subprocess.PIPE,
            stderr=None,
        )
        stdout, _ = proc.communicate()
        if proc.returncode == 0:
            lines = stdout.splitlines()
            for line in lines:
                if line.startswith(b"Fontconfig warning:"):
                    continue
                path = line.decode().strip().strip(":")
                if path:
                    return path
            return None

    def _create_nix(self):
        for name in STYLES["NORMAL"]:
            path = self._get_nix_font_path(self.font_name, name)
            if path is not None:
                self.fonts["NORMAL"] = ImageFont.truetype(path, self.font_size)
                break
        else:
            raise FontNotFound('No usable fonts named: "%s"' % self.font_name)
        for style in ("ITALIC", "BOLD", "BOLDITALIC"):
            for stylename in STYLES[style]:
                path = self._get_nix_font_path(self.font_name, stylename)
                if path is not None:
                    self.fonts[style] = ImageFont.truetype(path, self.font_size)
                    break
            else:
                if style == "BOLDITALIC":
                    self.fonts[style] = self.fonts["BOLD"]
                else:
                    self.fonts[style] = self.fonts["NORMAL"]

    def _get_mac_font_path(self, font_map, name, style):
        return font_map.get((name + " " + style).strip().lower())

    def _create_mac(self):
        font_map = {}
        for font_dir in (
            os.path.join(os.getenv("HOME"), "Library/Fonts/"),
            "/Library/Fonts/",
            "/System/Library/Fonts/",
        ):
            font_map.update(
                (os.path.splitext(f)[0].lower(), os.path.join(font_dir, f))
                for f in os.listdir(font_dir)
                if f.lower().endswith(("ttf", "ttc"))
            )

        for name in STYLES["NORMAL"]:
            path = self._get_mac_font_path(font_map, self.font_name, name)
            if path is not None:
                self.fonts["NORMAL"] = ImageFont.truetype(path, self.font_size)
                break
        else:
            raise FontNotFound('No usable fonts named: "%s"' % self.font_name)
        for style in ("ITALIC", "BOLD", "BOLDITALIC"):
            for stylename in STYLES[style]:
                path = self._get_mac_font_path(font_map, self.font_name, stylename)
                if path is not None:
                    self.fonts[style] = ImageFont.truetype(path, self.font_size)
                    break
            else:
                if style == "BOLDITALIC":
                    self.fonts[style] = self.fonts["BOLD"]
                else:
                    self.fonts[style] = self.fonts["NORMAL"]

    def _lookup_win(self, key, basename, styles, fail=False):
        for suffix in ("", " (TrueType)"):
            for style in styles:
                try:
                    valname = "%s%s%s" % (basename, style and " " + style, suffix)
                    val, _ = _winreg.QueryValueEx(key, valname)
                    return val
                except OSError:
                    continue
        else:
            if fail:
                raise FontNotFound(
                    "Font %s (%s) not found in registry" % (basename, styles[0])
                )
            return None

    def _create_win(self):
        lookuperror = None
        keynames = [
            (
                _winreg.HKEY_CURRENT_USER,
                r"Software\Microsoft\Windows NT\CurrentVersion\Fonts",
            ),
            (
                _winreg.HKEY_CURRENT_USER,
                r"Software\Microsoft\Windows\CurrentVersion\Fonts",
            ),
            (
                _winreg.HKEY_LOCAL_MACHINE,
                r"Software\Microsoft\Windows NT\CurrentVersion\Fonts",
            ),
            (
                _winreg.HKEY_LOCAL_MACHINE,
                r"Software\Microsoft\Windows\CurrentVersion\Fonts",
            ),
        ]
        for keyname in keynames:
            try:
                key = _winreg.OpenKey(*keyname)
                try:
                    path = self._lookup_win(key, self.font_name, STYLES["NORMAL"], True)
                    self.fonts["NORMAL"] = ImageFont.truetype(path, self.font_size)
                    for style in ("ITALIC", "BOLD", "BOLDITALIC"):
                        path = self._lookup_win(key, self.font_name, STYLES[style])
                        if path:
                            self.fonts[style] = ImageFont.truetype(path, self.font_size)
                        else:
                            if style == "BOLDITALIC":
                                self.fonts[style] = self.fonts["BOLD"]
                            else:
                                self.fonts[style] = self.fonts["NORMAL"]
                    return
                except FontNotFound as err:
                    lookuperror = err
                finally:
                    _winreg.CloseKey(key)
            except OSError:
                pass
        else:
            # If we get here, we checked all registry keys and had no luck
            # We can be in one of two situations now:
            # * All key lookups failed. In this case lookuperror is None and we
            #   will raise a generic error
            # * At least one lookup failed with a FontNotFound error. In this
            #   case, we will raise that as a more specific error
            if lookuperror:
                raise lookuperror
            raise FontNotFound("Can't open Windows font registry key")

    def get_char_size(self):
        """
        Get the character size.
        """
        return self.get_text_size("M")

    def get_text_size(self, text):
        """
        Get the text size (width, height).
        """
        font = self.fonts["NORMAL"]
        if hasattr(font, "getbbox"):  # Pillow >= 9.2.0
            return font.getbbox(text)[2:4]
        else:
            return font.getsize(text)

    def get_font(self, bold, oblique):
        """
        Get the font based on bold and italic flags.
        """
        if bold and oblique:
            return self.fonts["BOLDITALIC"]
        elif bold:
            return self.fonts["BOLD"]
        elif oblique:
            return self.fonts["ITALIC"]
        else:
            return self.fonts["NORMAL"]


class ImageFormatter(Formatter):
    """
    Create a PNG image from source code. This uses the Python Imaging Library to
    generate a pixmap from the source code.

    .. versionadded:: 0.10

    Additional options accepted:

    `image_format`
        An image format to output to that is recognised by PIL, these include:

        * "PNG" (default)
        * "JPEG"
        * "BMP"
        * "GIF"

    `line_pad`
        The extra spacing (in pixels) between each line of text.

        Default: 2

    `font_name`
        The font name to be used as the base font from which others, such as
        bold and italic fonts will be generated.  This really should be a
        monospace font to look sane.

        Default: "Courier New" on Windows, "Menlo" on Mac OS, and
                 "DejaVu Sans Mono" on \\*nix

    `font_size`
        The font size in points to be used.

        Default: 14

    `image_pad`
        The padding, in pixels to be used at each edge of the resulting image.

        Default: 10

    `line_numbers`
        Whether line numbers should be shown: True/False

        Default: True

    `line_number_start`
        The line number of the first line.

        Default: 1

    `line_number_step`
        The step used when printing line numbers.

        Default: 1

    `line_number_bg`
        The background colour (in "#123456" format) of the line number bar, or
        None to use the style background color.

        Default: "#eed"

    `line_number_fg`
        The text color of the line numbers (in "#123456"-like format).

        Default: "#886"

    `line_number_chars`
        The number of columns of line numbers allowable in the line number
        margin.

        Default: 2

    `line_number_bold`
        Whether line numbers will be bold: True/False

        Default: False

    `line_number_italic`
        Whether line numbers will be italicized: True/False

        Default: False

    `line_number_separator`
        Whether a line will be drawn between the line number area and the
        source code area: True/False

        Default: True

    `line_number_pad`
        The horizontal padding (in pixels) between the line number margin, and
        the source code area.

        Default: 6

    `hl_lines`
        Specify a list of lines to be highlighted.

        .. versionadded:: 1.2

        Default: empty list

    `hl_color`
        Specify the color for highlighting lines.

        .. versionadded:: 1.2

        Default: highlight color of the selected style
    """

    # Required by the pygments mapper
    name = "img"
    aliases = ["img", "IMG", "png"]
    filenames = ["*.png"]

    unicodeoutput = False

    default_image_format = "png"

    def __init__(self, **options):
        """
        See the class docstring for explanation of options.
        """
        if not pil_available:
            raise PilNotAvailable(
                "Python Imaging Library is required for this formatter"
            )
        Formatter.__init__(self, **options)
        self.encoding = "latin1"  # let pygments.format() do the right thing
        # Read the style
        self.styles = dict(self.style)
        if self.style.background_color is None:
            self.background_color = "#fff"
        else:
            self.background_color = self.style.background_color
        # Image options
        self.image_format = get_choice_opt(
            options,
            "image_format",
            ["png", "jpeg", "gif", "bmp"],
            self.default_image_format,
            normcase=True,
        )
        self.image_pad = get_int_opt(options, "image_pad", 10)
        self.line_pad = get_int_opt(options, "line_pad", 2)
        # The fonts
        fontsize = get_int_opt(options, "font_size", 14)
        self.fonts = FontManager(options.get("font_name", ""), fontsize)
        self.fontw, self.fonth = self.fonts.get_char_size()
        # Line number options
        self.line_number_fg = options.get("line_number_fg", "#886")
        self.line_number_bg = options.get("line_number_bg", "#eed")
        self.line_number_chars = get_int_opt(options, "line_number_chars", 2)
        self.line_number_bold = get_bool_opt(options, "line_number_bold", False)
        self.line_number_italic = get_bool_opt(options, "line_number_italic", False)
        self.line_number_pad = get_int_opt(options, "line_number_pad", 6)
        self.line_numbers = get_bool_opt(options, "line_numbers", True)
        self.line_number_separator = get_bool_opt(
            options, "line_number_separator", True
        )
        self.line_number_step = get_int_opt(options, "line_number_step", 1)
        self.line_number_start = get_int_opt(options, "line_number_start", 1)
        if self.line_numbers:
            self.line_number_width = (
                self.fontw * self.line_number_chars + self.line_number_pad * 2
            )
        else:
            self.line_number_width = 0
        self.hl_lines = []
        hl_lines_str = get_list_opt(options, "hl_lines", [])
        for line in hl_lines_str:
            try:
                self.hl_lines.append(int(line))
            except ValueError:
                pass
        self.hl_color = options.get("hl_color", self.style.highlight_color) or "#f90"
        self.drawables = []

    def get_style_defs(self, arg=""):
        raise NotImplementedError(
            "The -S option is meaningless for the image "
            "formatter. Use -O style=<stylename> instead."
        )

    def _get_line_height(self):
        """
        Get the height of a line.
        """
        return self.fonth + self.line_pad

    def _get_line_y(self, lineno):
        """
        Get the Y coordinate of a line number.
        """
        return lineno * self._get_line_height() + self.image_pad

    def _get_char_width(self):
        """
        Get the width of a character.
        """
        return self.fontw

    def _get_char_x(self, linelength):
        """
        Get the X coordinate of a character position.
        """
        return linelength + self.image_pad + self.line_number_width

    def _get_text_pos(self, linelength, lineno):
        """
        Get the actual position for a character and line position.
        """
        return self._get_char_x(linelength), self._get_line_y(lineno)

    def _get_linenumber_pos(self, lineno):
        """
        Get the actual position for the start of a line number.
        """
        return (self.image_pad, self._get_line_y(lineno))

    def _get_text_color(self, style):
        """
        Get the correct color for the token from the style.
        """
        if style["color"] is not None:
            fill = "#" + style["color"]
        else:
            fill = "#000"
        return fill

    def _get_text_bg_color(self, style):
        """
        Get the correct background color for the token from the style.
        """
        if style["bgcolor"] is not None:
            bg_color = "#" + style["bgcolor"]
        else:
            bg_color = None
        return bg_color

    def _get_style_font(self, style):
        """
        Get the correct font for the style.
        """
        return self.fonts.get_font(style["bold"], style["italic"])

    def _get_image_size(self, maxlinelength, maxlineno):
        """
        Get the required image size.
        """
        return (
            self._get_char_x(maxlinelength) + self.image_pad,
            self._get_line_y(maxlineno + 0) + self.image_pad,
        )

    def _draw_linenumber(self, posno, lineno):
        """
        Remember a line number drawable to paint later.
        """
        self._draw_text(
            self._get_linenumber_pos(posno),
            str(lineno).rjust(self.line_number_chars),
            font=self.fonts.get_font(self.line_number_bold, self.line_number_italic),
            text_fg=self.line_number_fg,
            text_bg=None,
        )

    def _draw_text(self, pos, text, font, text_fg, text_bg):
        """
        Remember a single drawable tuple to paint later.
        """
        self.drawables.append((pos, text, font, text_fg, text_bg))

    def _create_drawables(self, tokensource):
        """
        Create drawables for the token content.
        """
        lineno = charno = maxcharno = 0
        maxlinelength = linelength = 0
        for ttype, value in tokensource:
            while ttype not in self.styles:
                ttype = ttype.parent
            style = self.styles[ttype]
            # TODO: make sure tab expansion happens earlier in the chain.  It
            # really ought to be done on the input, as to do it right here is
            # quite complex.
            value = value.expandtabs(4)
            lines = value.splitlines(True)
            # print lines
            for i, line in enumerate(lines):
                temp = line.rstrip("\n")
                if temp:
                    self._draw_text(
                        self._get_text_pos(linelength, lineno),
                        temp,
                        font=self._get_style_font(style),
                        text_fg=self._get_text_color(style),
                        text_bg=self._get_text_bg_color(style),
                    )
                    temp_width, _ = self.fonts.get_text_size(temp)
                    linelength += temp_width
                    maxlinelength = max(maxlinelength, linelength)
                    charno += len(temp)
                    maxcharno = max(maxcharno, charno)
                if line.endswith("\n"):
                    # add a line for each extra line in the value
                    linelength = 0
                    charno = 0
                    lineno += 1
        self.maxlinelength = maxlinelength
        self.maxcharno = maxcharno
        self.maxlineno = lineno

    def _draw_line_numbers(self):
        """
        Create drawables for the line numbers.
        """
        if not self.line_numbers:
            return
        for p in range(self.maxlineno):
            n = p + self.line_number_start
            if (n % self.line_number_step) == 0:
                self._draw_linenumber(p, n)

    def _paint_line_number_bg(self, im):
        """
        Paint the line number background on the image.
        """
        if not self.line_numbers:
            return
        if self.line_number_fg is None:
            return
        draw = ImageDraw.Draw(im)
        recth = im.size[-1]
        rectw = self.image_pad + self.line_number_width - self.line_number_pad
        draw.rectangle([(0, 0), (rectw, recth)], fill=self.line_number_bg)
        if self.line_number_separator:
            draw.line([(rectw, 0), (rectw, recth)], fill=self.line_number_fg)
        del draw

    def format(self, tokensource, outfile):
        """
        Format ``tokensource``, an iterable of ``(tokentype, tokenstring)``
        tuples and write it into ``outfile``.

        This implementation calculates where it should draw each token on the
        pixmap, then calculates the required pixmap size and draws the items.
        """
        self._create_drawables(tokensource)
        self._draw_line_numbers()
        im = Image.new(
            "RGB",
            self._get_image_size(self.maxlinelength, self.maxlineno),
            self.background_color,
        )
        self._paint_line_number_bg(im)
        draw = ImageDraw.Draw(im)
        # Highlight
        if self.hl_lines:
            x = self.image_pad + self.line_number_width - self.line_number_pad + 1
            recth = self._get_line_height()
            rectw = im.size[0] - x
            for linenumber in self.hl_lines:
                y = self._get_line_y(linenumber - 1)
                draw.rectangle([(x, y), (x + rectw, y + recth)], fill=self.hl_color)
        for pos, value, font, text_fg, text_bg in self.drawables:
            if text_bg:
                text_size = draw.textsize(text=value, font=font)
                draw.rectangle(
                    [pos[0], pos[1], pos[0] + text_size[0], pos[1] + text_size[1]],
                    fill=text_bg,
                )
            draw.text(pos, value, font=font, fill=text_fg)
        im.save(outfile, self.image_format.upper())


# Add one formatter per format, so that the "-f gif" option gives the correct result
# when used in pygmentize.


class GifImageFormatter(ImageFormatter):
    """
    Create a GIF image from source code. This uses the Python Imaging Library to
    generate a pixmap from the source code.

    .. versionadded:: 1.0
    """

    name = "img_gif"
    aliases = ["gif"]
    filenames = ["*.gif"]
    default_image_format = "gif"


class JpgImageFormatter(ImageFormatter):
    """
    Create a JPEG image from source code. This uses the Python Imaging Library to
    generate a pixmap from the source code.

    .. versionadded:: 1.0
    """

    name = "img_jpg"
    aliases = ["jpg", "jpeg"]
    filenames = ["*.jpg"]
    default_image_format = "jpeg"


class BmpImageFormatter(ImageFormatter):
    """
    Create a bitmap image from source code. This uses the Python Imaging Library to
    generate a pixmap from the source code.

    .. versionadded:: 1.0
    """

    name = "img_bmp"
    aliases = ["bmp", "bitmap"]
    filenames = ["*.bmp"]
    default_image_format = "bmp"



"""Build wheels/sdists by installing build deps to a temporary environment.
"""

import logging
import os
import shutil
import sys
from subprocess import check_call
from sysconfig import get_paths
from tempfile import mkdtemp

from ._compat import tomllib
from .wrappers import LoggerWrapper, Pep517HookCaller

log = logging.getLogger(__name__)


def _load_pyproject(source_dir):
    with open(
        os.path.join(source_dir, "pyproject.toml"),
        "rb",
    ) as f:
        pyproject_data = tomllib.load(f)
    buildsys = pyproject_data["build-system"]
    return (
        buildsys["requires"],
        buildsys["build-backend"],
        buildsys.get("backend-path"),
    )


class BuildEnvironment:
    """Context manager to install build deps in a simple temporary environment

    Based on code I wrote for pip, which is MIT licensed.
    """

    # Copyright (c) 2008-2016 The pip developers (see AUTHORS.txt file)
    #
    # Permission is hereby granted, free of charge, to any person obtaining
    # a copy of this software and associated documentation files (the
    # "Software"), to deal in the Software without restriction, including
    # without limitation the rights to use, copy, modify, merge, publish,
    # distribute, sublicense, and/or sell copies of the Software, and to
    # permit persons to whom the Software is furnished to do so, subject to
    # the following conditions:
    #
    # The above copyright notice and this permission notice shall be
    # included in all copies or substantial portions of the Software.
    #
    # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    # NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
    # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
    # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
    # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

    path = None

    def __init__(self, cleanup=True):
        self._cleanup = cleanup

    def __enter__(self):
        self.path = mkdtemp(prefix="pep517-build-env-")
        log.info("Temporary build environment: %s", self.path)

        self.save_path = os.environ.get("PATH", None)
        self.save_pythonpath = os.environ.get("PYTHONPATH", None)

        install_scheme = "nt" if (os.name == "nt") else "posix_prefix"
        install_dirs = get_paths(
            install_scheme,
            vars={
                "base": self.path,
                "platbase": self.path,
            },
        )

        scripts = install_dirs["scripts"]
        if self.save_path:
            os.environ["PATH"] = scripts + os.pathsep + self.save_path
        else:
            os.environ["PATH"] = scripts + os.pathsep + os.defpath

        if install_dirs["purelib"] == install_dirs["platlib"]:
            lib_dirs = install_dirs["purelib"]
        else:
            lib_dirs = install_dirs["purelib"] + os.pathsep + install_dirs["platlib"]
        if self.save_pythonpath:
            os.environ["PYTHONPATH"] = lib_dirs + os.pathsep + self.save_pythonpath
        else:
            os.environ["PYTHONPATH"] = lib_dirs

        return self

    def pip_install(self, reqs):
        """Install dependencies into this env by calling pip in a subprocess"""
        if not reqs:
            return
        log.info("Calling pip to install %s", reqs)
        cmd = [
            sys.executable,
            "-m",
            "pip",
            "install",
            "--ignore-installed",
            "--prefix",
            self.path,
        ] + list(reqs)
        check_call(
            cmd,
            stdout=LoggerWrapper(log, logging.INFO),
            stderr=LoggerWrapper(log, logging.ERROR),
        )

    def __exit__(self, exc_type, exc_val, exc_tb):
        needs_cleanup = (
            self._cleanup and self.path is not None and os.path.isdir(self.path)
        )
        if needs_cleanup:
            shutil.rmtree(self.path)

        if self.save_path is None:
            os.environ.pop("PATH", None)
        else:
            os.environ["PATH"] = self.save_path

        if self.save_pythonpath is None:
            os.environ.pop("PYTHONPATH", None)
        else:
            os.environ["PYTHONPATH"] = self.save_pythonpath


def build_wheel(source_dir, wheel_dir, config_settings=None):
    """Build a wheel from a source directory using PEP 517 hooks.

    :param str source_dir: Source directory containing pyproject.toml
    :param str wheel_dir: Target directory to create wheel in
    :param dict config_settings: Options to pass to build backend

    This is a blocking function which will run pip in a subprocess to install
    build requirements.
    """
    if config_settings is None:
        config_settings = {}
    requires, backend, backend_path = _load_pyproject(source_dir)
    hooks = Pep517HookCaller(source_dir, backend, backend_path)

    with BuildEnvironment() as env:
        env.pip_install(requires)
        reqs = hooks.get_requires_for_build_wheel(config_settings)
        env.pip_install(reqs)
        return hooks.build_wheel(wheel_dir, config_settings)


def build_sdist(source_dir, sdist_dir, config_settings=None):
    """Build an sdist from a source directory using PEP 517 hooks.

    :param str source_dir: Source directory containing pyproject.toml
    :param str sdist_dir: Target directory to place sdist in
    :param dict config_settings: Options to pass to build backend

    This is a blocking function which will run pip in a subprocess to install
    build requirements.
    """
    if config_settings is None:
        config_settings = {}
    requires, backend, backend_path = _load_pyproject(source_dir)
    hooks = Pep517HookCaller(source_dir, backend, backend_path)

    with BuildEnvironment() as env:
        env.pip_install(requires)
        reqs = hooks.get_requires_for_build_sdist(config_settings)
        env.pip_install(reqs)
        return hooks.build_sdist(sdist_dir, config_settings)



"""Build a project using PEP 517 hooks.
"""
import argparse
import logging
import os
import shutil
import tempfile

from ._compat import tomllib
from .envbuild import BuildEnvironment
from .wrappers import Pep517HookCaller

log = logging.getLogger(__name__)


def validate_system(system):
    """
    Ensure build system has the requisite fields.
    """
    required = {"requires", "build-backend"}
    if not (required <= set(system)):
        message = "Missing required fields: {missing}".format(
            missing=required - set(system),
        )
        raise ValueError(message)


def load_system(source_dir):
    """
    Load the build system from a source dir (pyproject.toml).
    """
    pyproject = os.path.join(source_dir, "pyproject.toml")
    with open(pyproject, "rb") as f:
        pyproject_data = tomllib.load(f)
    return pyproject_data["build-system"]


def compat_system(source_dir):
    """
    Given a source dir, attempt to get a build system backend
    and requirements from pyproject.toml. Fallback to
    setuptools but only if the file was not found or a build
    system was not indicated.
    """
    try:
        system = load_system(source_dir)
    except (FileNotFoundError, KeyError):
        system = {}
    system.setdefault(
        "build-backend",
        "setuptools.build_meta:__legacy__",
    )
    system.setdefault("requires", ["setuptools", "wheel"])
    return system


def _do_build(hooks, env, dist, dest):
    get_requires_name = "get_requires_for_build_{dist}".format(**locals())
    get_requires = getattr(hooks, get_requires_name)
    reqs = get_requires({})
    log.info("Got build requires: %s", reqs)

    env.pip_install(reqs)
    log.info("Installed dynamic build dependencies")

    with tempfile.TemporaryDirectory() as td:
        log.info("Trying to build %s in %s", dist, td)
        build_name = "build_{dist}".format(**locals())
        build = getattr(hooks, build_name)
        filename = build(td, {})
        source = os.path.join(td, filename)
        shutil.move(source, os.path.join(dest, os.path.basename(filename)))


def build(source_dir, dist, dest=None, system=None):
    system = system or load_system(source_dir)
    dest = os.path.join(source_dir, dest or "dist")
    os.makedirs(dest, exist_ok=True)

    validate_system(system)
    hooks = Pep517HookCaller(
        source_dir, system["build-backend"], system.get("backend-path")
    )

    with BuildEnvironment() as env:
        env.pip_install(system["requires"])
        _do_build(hooks, env, dist, dest)


parser = argparse.ArgumentParser()
parser.add_argument(
    "source_dir",
    help="A directory containing pyproject.toml",
)
parser.add_argument(
    "--binary",
    "-b",
    action="store_true",
    default=False,
)
parser.add_argument(
    "--source",
    "-s",
    action="store_true",
    default=False,
)
parser.add_argument(
    "--out-dir",
    "-o",
    help="Destination in which to save the builds relative to source dir",
)


def main(args):
    log.warning(
        "pep517.build is deprecated. "
        "Consider switching to https://pypi.org/project/build/"
    )

    # determine which dists to build
    dists = list(
        filter(
            None,
            (
                "sdist" if args.source or not args.binary else None,
                "wheel" if args.binary or not args.source else None,
            ),
        )
    )

    for dist in dists:
        build(args.source_dir, dist, args.out_dir)


if __name__ == "__main__":
    main(parser.parse_args())



import sys
import os
import re
import importlib
import warnings


is_pypy = "__pypy__" in sys.builtin_module_names


warnings.filterwarnings("ignore", r".+ distutils\b.+ deprecated", DeprecationWarning)


def warn_distutils_present():
    if "distutils" not in sys.modules:
        return
    if is_pypy and sys.version_info < (3, 7):
        # PyPy for 3.6 unconditionally imports distutils, so bypass the warning
        # https://foss.heptapod.net/pypy/pypy/-/blob/be829135bc0d758997b3566062999ee8b23872b4/lib-python/3/site.py#L250
        return
    warnings.warn(
        "Distutils was imported before Setuptools, but importing Setuptools "
        "also replaces the `distutils` module in `sys.modules`. This may lead "
        "to undesirable behaviors or errors. To avoid these issues, avoid "
        "using distutils directly, ensure that setuptools is installed in the "
        "traditional way (e.g. not an editable install), and/or make sure "
        "that setuptools is always imported before distutils."
    )


def clear_distutils():
    if "distutils" not in sys.modules:
        return
    warnings.warn("Setuptools is replacing distutils.")
    mods = [name for name in sys.modules if re.match(r"distutils\b", name)]
    for name in mods:
        del sys.modules[name]


def enabled():
    """
    Allow selection of distutils by environment variable.
    """
    which = os.environ.get("SETUPTOOLS_USE_DISTUTILS", "stdlib")
    return which == "local"


def ensure_local_distutils():
    clear_distutils()
    distutils = importlib.import_module("setuptools._distutils")
    distutils.__name__ = "distutils"
    sys.modules["distutils"] = distutils

    # sanity check that submodules load as expected
    core = importlib.import_module("distutils.core")
    assert "_distutils" in core.__file__, core.__file__


def do_override():
    """
    Ensure that the local copy of distutils is preferred over stdlib.

    See https://github.com/pypa/setuptools/issues/417#issuecomment-392298401
    for more motivation.
    """
    if enabled():
        warn_distutils_present()
        ensure_local_distutils()


class DistutilsMetaFinder:
    def find_spec(self, fullname, path, target=None):
        if path is not None:
            return

        method_name = "spec_for_{fullname}".format(**locals())
        method = getattr(self, method_name, lambda: None)
        return method()

    def spec_for_distutils(self):
        import importlib.abc
        import importlib.util

        class DistutilsLoader(importlib.abc.Loader):
            def create_module(self, spec):
                return importlib.import_module("setuptools._distutils")

            def exec_module(self, module):
                pass

        return importlib.util.spec_from_loader("distutils", DistutilsLoader())

    def spec_for_pip(self):
        """
        Ensure stdlib distutils when running under pip.
        See pypa/pip#8761 for rationale.
        """
        if self.pip_imported_during_build():
            return
        clear_distutils()
        self.spec_for_distutils = lambda: None

    @staticmethod
    def pip_imported_during_build():
        """
        Detect if pip is being imported in a build script. Ref #2355.
        """
        import traceback

        return any(
            frame.f_globals["__file__"].endswith("setup.py")
            for frame, line in traceback.walk_stack(None)
        )


DISTUTILS_FINDER = DistutilsMetaFinder()


def add_shim():
    sys.meta_path.insert(0, DISTUTILS_FINDER)


def remove_shim():
    try:
        sys.meta_path.remove(DISTUTILS_FINDER)
    except ValueError:
        pass
